/*********************************************************************************
ColorSpaceGui.java - Implementa a interface grfica do programa.

Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Implementa a interface grfica do programa.
    Implementa o sistema de abertura de imagens.

Sada:
 
    Interface grafica com o usurio.

Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda

**********************************************************************************/

import java.awt.Component;
import java.awt.Toolkit;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.util.StringTokenizer;
import java.util.Vector;
import javax.imageio.ImageIO;
import javax.swing.ActionMap;
import javax.swing.ButtonGroup;
import javax.swing.ButtonModel;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;
import javax.swing.JTree;
import javax.swing.JViewport;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreeNode;
import javax.swing.tree.TreeSelectionModel;

public class ColorSpaceGui extends JFrame implements MouseListener {
    public static Vector imagensAbertas = new Vector();
    private DefaultMutableTreeNode top1 =  new DefaultMutableTreeNode("Dir");
    
    private File fileImgPan;
    private File fileImgRed;
    private File fileImgBlue;
    private File fileImgGreen;
    private File fileImgHue;
    private File fileImgLightness;
    private File fileImgSaturation;
    private File fileImgIntensity;
    private File fileImgBanda1;
    private File fileImgBanda2;
    private File fileImgBanda3;
    
    private ConfiguracoesFrame cfg;
    String opcaoSelecionada = "";
    
    /**
     * Construtor do Programa "Fuso espectral de imagens de satlite no espao de cores"
     */
    public ColorSpaceGui() {
        super("Fuso espectral de imagens de satlite no espao de cores");
        
        setIconImage(Toolkit.getDefaultToolkit().getImage("src//image.png"));
        initComponents();
        
        jToolBar4.setVisible(false);
        jMenu2.setEnabled(false);
                
        jProgressBar1.setValue(0);
        jProgressBar1.setStringPainted(true);
        
        cfg = new ConfiguracoesFrame();
        montarArvore( System.getProperty("user.dir") , top1);
    }
    
    /**
     * Mtodo: Abre um unico arquivo de imagem de um determinado diretorio
     *         retornando um arquivo contendo uma imagem.
     */
    private File abreImagem() {
        File img = null;
        JFileChooser fileChooser = new JFileChooser(".");
        String dir = "imagens";
        fileChooser.setCurrentDirectory(new java.io.File(dir));
        fileChooser.setDialogTitle("Abre arquivo com imagem");
        fileChooser.setMultiSelectionEnabled(true);
        int status = fileChooser.showOpenDialog(null);
        if (status == JFileChooser.APPROVE_OPTION) {
            img = fileChooser.getSelectedFile();
            if(filtroImg(img)==1) {
                JOptionPane.showMessageDialog(this,"Este arquivo no  reconhecido como imagem!",
                        "Erro: Imagem no reconhecida",JOptionPane.ERROR_MESSAGE);
                return null;
            }
        } else
            if (status == JFileChooser.CANCEL_OPTION)
                img = null;
        
        return img;
    }
    
    /**
     * Mtodo: Abre um ou mais arquivos de imagens de um determinado diretorio e
     *         para cada arquivo chama a funco addImagemAba
     */
    private void abrirImagemAba() {
        File[] arquivos;
        
        JFileChooser fileChooser = new JFileChooser(".");
        String dir = "imagens";
        fileChooser.setCurrentDirectory(new java.io.File(dir));
        fileChooser.setDialogTitle("Abre arquivos com imagens");
        fileChooser.setMultiSelectionEnabled(true);
        int status = fileChooser.showOpenDialog(null);
        
        if (status == JFileChooser.APPROVE_OPTION) {
            arquivos = fileChooser.getSelectedFiles();
            for (int i = 0; i < arquivos.length; i++) {
                if(filtroImg(arquivos[i])==0)
                    addImagemAba(arquivos[i]);
                else JOptionPane.showMessageDialog(this,"Este arquivo no  reconhecido como imagem!",
                        "Erro: Imagem no reconhecida",JOptionPane.ERROR_MESSAGE);
            }
        } else
            if (status == JFileChooser.CANCEL_OPTION)
                arquivos = null;
    }
    
    /**
     * Mtodo: Insere uma imagem dentro do manipulador de abas do sistema a
     *         partir de um arquivo passado por parametro.
     * 
     * @param fileImgAbre
     */
    private void addImagemAba(File fileImgAbre ) {
        if(fileImgAbre != null) {
            BufferedImage imagem = null;
            
            try {
                imagem = ImageIO.read(fileImgAbre);
                
                JLabel lab = new JLabel(new ImageIcon(imagem));
                JScrollPane scroll = new JScrollPane(lab);
                scroll.addMouseListener(this);
                scroll.setName("ScrollImagem");
                
                jTabbedPane2.addTab(fileImgAbre.getName(), scroll );
                jTabbedPane2.setSelectedIndex(jTabbedPane2.getTabCount()-1);
                
                imagensAbertas.add(new Manipulador(fileImgAbre, 0, 1.00f));
                
               
                
            } catch(Exception e) {
                System.out.println("abreImagens: Problema lendo '" + fileImgAbre + "'.");
                JOptionPane.showMessageDialog(this,"No foi possivel abrir o arquivo!\n\n" +
                        "Verifique a integridade e a\n" +
                        "Permisso do arquivo.",
                        "Erro: Imagem no reconhecida",JOptionPane.ERROR_MESSAGE);
                e.printStackTrace();
            }
        }
    }
    
    /**
     * Mtodo: Fecha a aba que esta atualmente selecionada.
     */
    private void fecharItem() {
        if(jTabbedPane2.getTabCount()!=0) {
            System.out.println("Removendo o item"+ jTabbedPane2.getSelectedIndex());
            int indice = jTabbedPane2.getSelectedIndex();
            
            jTabbedPane2.remove(indice);
            imagensAbertas.remove(indice);
        }
        
        if(jTabbedPane2.getTabCount()==0) {
            jToolBar4.setVisible(false);
            jMenu2.setEnabled(false);
        }
    }
    
    /**
     * Mtodo: Abre para o usuario um seletor de arquivo para que possa escolher
     *         e salvar a imagem que estiver selecionada no momento.
     */
    private void salvarImagem() {
        System.out.println("Salvar Imagem");
        Manipulador man = null;
        File arq = null;
        JTabbedPane pane = null;
        BufferedImage img = null;
        JScrollPane scrollImagem = null;
        
        if(jTabbedPane2.getTabCount() == 0) {
            JOptionPane.showMessageDialog(this,"   Nenhuma Imagem Selecionada!\nSelecione uma Imagem e tente novamente!",
                    "Erro: Nenhuma Imagem Selecionada",JOptionPane.ERROR_MESSAGE);
            return;
        }
        
        
        String dir = System.getProperty("user.dir");
        
        JFileChooser fcSalva = new JFileChooser(dir + "//imagens");
        //fcSalva.setCurrentDirectory(new java.io.File(dir));
        fcSalva.setAcceptAllFileFilterUsed(true);
        int returnVal = fcSalva.showSaveDialog(this);
        
        if (returnVal == JFileChooser.APPROVE_OPTION) {
            dir = fcSalva.getSelectedFile().getParent();
            System.out.println(dir);
            File file = fcSalva.getSelectedFile();
            String search = ".";
            String filePath = file.getPath();
            int ki = filePath.indexOf(search);
            if (ki < 0)
                file = new File(filePath+".png");
            else
                file = new File(filePath.substring(0, ki)+".png");
            
            try {
                try {
                    man = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                    arq = man.getArquivo();
                }catch (Exception ex) {
                    Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                    pane = (JTabbedPane) vect.get(0);
                    man = (Manipulador) vect.get(pane.getSelectedIndex()+1);
                    arq = man.getArquivo();
                    
                    System.out.println("Indice Alto: "+ jTabbedPane2.getSelectedIndex());
                    System.out.println("Indice Baixo: "+ pane.getSelectedIndex());
                }
                
                img = JAIZoom.Zoom(arq.getPath(), man.getPerc_zoom() , man.getPerc_zoom() , cfg.getMetodoSelecionado());
                
                Equaliza eq = new Equaliza(img);
                img = eq.aplicarMetodo(man.getEqualizacao());
                
                ImageIO.write(img, "png", file);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }
    }
    
    /**
     * Mtodo: Salva todas as imagens que esto abertas no momento
     */
    private void salvarTudo() {
        Manipulador man = null;
        File arq = null;
        JTabbedPane pane = null;
        BufferedImage img = null;
        JScrollPane scrollImagem = null;
        System.out.println("Salvando todos os Arquivos abertos");
        
        //Percorre todos as  imagens abertas e as salva.
        for(int i=0;i<imagensAbertas.size();i++) {
            try {
                man = (Manipulador) imagensAbertas.get(i);
                arq = man.getArquivo();
                
                // >> salva o arquivo.
                img = JAIZoom.Zoom(arq.getPath(), man.getPerc_zoom() ,
                        man.getPerc_zoom() , cfg.getMetodoSelecionado());
                
                Equaliza eq = new Equaliza(img);
                img = eq.aplicarMetodo(man.getEqualizacao());
                
                salvarArquivo(img, arq.getName());
            }catch (Exception ex) {
                Vector vect = (Vector) imagensAbertas.get(i);
                pane = (JTabbedPane) vect.get(0);
                for(int j=1;j<vect.size();j++) {
                    man = (Manipulador) vect.get(j);
                    scrollImagem = (JScrollPane) pane.getSelectedComponent();
                    arq = man.getArquivo();
                    
                    // >> salva o arquivo.
                    img = JAIZoom.Zoom(arq.getPath(), man.getPerc_zoom() ,
                            man.getPerc_zoom() , cfg.getMetodoSelecionado());
                    
                    Equaliza eq = new Equaliza(img);
                    img = eq.aplicarMetodo(man.getEqualizacao());
                    
                    salvarArquivo(img, arq.getName());
                }
            }
        }
    }
    
    /**
     * Mtodo: Salva uma imagem no arquivo.
     */
    private void salvarArquivo(BufferedImage img, String nome) {
        
        String dir = System.getProperty("user.dir") + "//imagens";
        
        // retirar o formato de dentro da string
        StringTokenizer tokem = new StringTokenizer(nome);
        nome = tokem.nextToken(".");
        
        try {
            File novo = new File(dir +"//"+ nome + ".png");
            ImageIO.write(img, "png", novo);
            System.out.println("Arquivo Salvo:" + novo.getName() + "v: " + nome);
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
    
    
    /**
     * Mtodo: Aplica um tipo de equalizao, que  passada por parametro, sobre
     *         a imagem que esta selecionada no momento.
     */
    private void aplicarEqualizacao(String eq) {
        Manipulador man = null;
        File arq = null;
        JTabbedPane pane = null;
        BufferedImage img = null;
        JScrollPane scrollImagem = null;
        
        try {
            man = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            arq = man.getArquivo();
            scrollImagem = (JScrollPane) jTabbedPane2.getSelectedComponent();
        }catch (Exception ex) {
            Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            pane = (JTabbedPane) vect.get(0);
            man = (Manipulador) vect.get(pane.getSelectedIndex()+1);
            scrollImagem = (JScrollPane) pane.getSelectedComponent();
            arq = man.getArquivo();
            
            System.out.println("Indice Alto: "+ jTabbedPane2.getSelectedIndex());
            System.out.println("Indice Baixo: "+ pane.getSelectedIndex());
        }
        
        man.setEqualizacao(eq);
        
        float fator = man.getPerc_zoom();
        zoomImagem( 0, fator);
    }
    
    /**
     * Mtodo: Cria um histograma para a imagem que estiver selecionada.
     */
    private void criarHistograma() {
        System.out.println("Gerando Histograma para a Imagem");
        Manipulador man = null;
        File imgHist = null;
        JTabbedPane pane = null;
        BufferedImage img = null;
        JScrollPane scrollImagem = null;
        
        if(jTabbedPane2.getTabCount() == 0) {
            JOptionPane.showMessageDialog(this,"   Nenhuma Imagem Selecionada!\nSelecione uma Imagem e tente novamente!",
                    "Erro: Nenhuma Imagem Selecionada",JOptionPane.ERROR_MESSAGE);
            return;
        }
        
        try {
            man = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            imgHist = man.getArquivo();
            
            Equaliza eq = new Equaliza(imgHist);
            img = eq.aplicarMetodo(man.getEqualizacao());
        }catch (Exception ex) {
            Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            pane = (JTabbedPane) vect.get(0);
            man = (Manipulador) vect.get(pane.getSelectedIndex()+1);
            imgHist = man.getArquivo();
            
            Equaliza eq = new Equaliza(imgHist);
            img = eq.aplicarMetodo(man.getEqualizacao());   
        }
        
        HistogramaFC hist = new HistogramaFC(img, imgHist.getName() );
    }
    
    private void sairPrograma() {
        if(jTabbedPane2.getTabCount() > 0) {
            String opc[] = {"Sim","No","Cancelar"};
            int res = JOptionPane.showOptionDialog(this,"Deseja salvar todos os arquivos antes de sair?",
                    "Saindo do programa", JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE,null,opc,null);
            
            if(res == 0) {
                salvarTudo();
                System.exit(0);
            } else if(res == 1) {
                System.exit(0);
            } else if(res == 2) {
                return;
            }
        } else {
            System.exit(0);
        }
    }
    
    private void abrirArquivoArvore() {
        DefaultMutableTreeNode ItemSelecionado = (DefaultMutableTreeNode)tree1.getLastSelectedPathComponent();
        
        File arquivo = null;
        
        try {
            TreeNode auxiliar = ItemSelecionado.getParent();
            String pathname = ItemSelecionado.toString();
            
            while(auxiliar.toString().compareTo("Dir") != 0) {
                pathname = auxiliar.toString()+ "/" + pathname;
                auxiliar = auxiliar.getParent();
            }
            
            arquivo = new File(pathname);
            if(arquivo == null || filtroImg(arquivo)==1 ) {
                System.out.println("Arquivo nao  imagem");
                return;
            }
            
            addImagemAba(arquivo );
        } catch( Exception excp ) {
            
        }
    }
    
    /** Monta a Arvore de diretorios,
     *      Entrada: Pathname do diretorio corrente, Arvore de diretorio
     *      Saida: Arvore montada em top com os componentes do pathname
     */
    private void montarArvore( String pathname, DefaultMutableTreeNode top ){
        // Crio um arquivo diretorio para obter todos os dados do diretorio corrente
        File diretorio = new File(pathname);
        File fList[] = diretorio.listFiles();
        
        // Busco todos os arquivos e fao a insero na arvore
        for (int i=0; i < fList.length; i++) {
            
            // Se for arquivo
            if (fList[i].isFile()) {
                if(filtroImg(fList[i]) == 0) {
                    DefaultMutableTreeNode arquivo = new DefaultMutableTreeNode(fList[i].getName());
                    top.add(arquivo);
                }
            }
            // Senao entao  diretorio, chamar denovo a funao para montar o proximo diretrio
            else {
                DefaultMutableTreeNode dir = new DefaultMutableTreeNode(fList[i].getName());
                montarArvore(fList[i].toString(), dir);
                top.add(dir);
            }
        }
    }
    
    /** Filtra os arquivos que so imagens
     *      Entrada Arquivo.
     *      retorna 0 se for imagem
     *      retorna 1 se nao for imagem
     */
    private int filtroImg(File arq) {
        try {
            String nome = arq.getName();
            StringTokenizer tokem = new StringTokenizer(nome,".");
            String ext;
            
            while(true) {
                String tok = tokem.nextToken();
                if(tokem.hasMoreTokens()) {
                    nome += tok;
                } else {
                    ext = tok;
                    break;
                }
            }
            
            //System.out.println("Nome:" + nome + "   " + ext );
            
            if(ext.equals("png") || ext.equals("tif") || ext.equals("tiff") ||
                    ext.equals("jpg") || ext.equals("bmp") || ext.equals("gif"))
                return 0;
            else return 1;
        } catch (Exception ex) {
            return 1;
        }
    }
    
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    
    public void criarToolBar() {
        jToolBar1 = new JToolBar();
        jToolBar3 = new JToolBar();
        jToolBar4 = new JToolBar();
        abreImgBtn = new JButton();
        salvarImgBtn = new JButton();
        fechaItemBtn = new JButton();
        configZoomBtn = new JButton();
        zoomOutBtn = new JButton();
        zoomInBtn = new JButton();
        zoomNormalBtn = new JButton();
        fatorLabel = new JLabel();
        selecaoZoomCB = new JComboBox();
        jLabel16 = new JLabel();
        jComboBox2 = new JComboBox();
        
        jToolBar1.setFloatable(false);
        jToolBar1.setBorderPainted(false);
        jToolBar1.setEnabled(false);
        abreImgBtn.setIcon(new javax.swing.ImageIcon("src/folder_picture.png"));
        abreImgBtn.setText("Abrir");
        abreImgBtn.setToolTipText("Abrir Imagem");
        abreImgBtn.setFocusPainted(false);
        abreImgBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                abrirImagemAba();
            }
        });
        
        jToolBar3.add(abreImgBtn);
        
        salvarImgBtn.setIcon(new javax.swing.ImageIcon("src//disk.png"));
        salvarImgBtn.setText("Salvar");
        salvarImgBtn.setToolTipText("Salvar Imagem");
        salvarImgBtn.setFocusPainted(false);
        salvarImgBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                salvarImagem();
            }
        });
        
        jToolBar3.add(salvarImgBtn);
        
        fechaItemBtn.setIcon(new javax.swing.ImageIcon("src//cross.png"));
        fechaItemBtn.setText("Fechar");
        fechaItemBtn.setToolTipText("Fechar Item");
        fechaItemBtn.setFocusPainted(false);
        fechaItemBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fecharItem();
            }
        });
        
        jToolBar3.add(fechaItemBtn);
        
        configZoomBtn.setIcon(new javax.swing.ImageIcon("src//cog.png"));
        configZoomBtn.setText("Configura\u00e7\u00f5es");
        configZoomBtn.setToolTipText("Configura\u00e7\u00f5es de Zoom");
        configZoomBtn.setFocusPainted(false);
        configZoomBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cfg.setVisible(true);
            }
        });
        
        jToolBar3.add(configZoomBtn);
        
        jToolBar1.add(jToolBar3);
        
        zoomOutBtn.setIcon(new javax.swing.ImageIcon("src//zoom_out.png"));
        zoomOutBtn.setText("Zoom Out");
        zoomOutBtn.setToolTipText("Zoom Out");
        zoomOutBtn.setFocusPainted(false);
        zoomOutBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomImagem( -1, 0.10f);
            }
        });
        
        jToolBar4.add(zoomOutBtn);
        
        zoomInBtn.setIcon(new javax.swing.ImageIcon("src//zoom_in.png"));
        zoomInBtn.setText("Zoom In");
        zoomInBtn.setToolTipText("Zoom In");
        zoomInBtn.setFocusPainted(false);
        zoomInBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomImagem( 1, 0.10f);
            }
        });
        
        jToolBar4.add(zoomInBtn);
        
        zoomNormalBtn.setIcon(new javax.swing.ImageIcon("src//zoom.png"));
        zoomNormalBtn.setText("Normal");
        zoomNormalBtn.setToolTipText("Normal");
        zoomNormalBtn.setFocusPainted(false);
        zoomNormalBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomImagem( 0, 1.00f);
            }
        });
        
        jToolBar4.add(zoomNormalBtn);
        
        fatorLabel.setText(" Fator: ");
        fatorLabel.setMaximumSize(new java.awt.Dimension(40, 25));
        fatorLabel.setMinimumSize(new java.awt.Dimension(40, 25));
        fatorLabel.setPreferredSize(new java.awt.Dimension(40, 25));
        jToolBar4.add(fatorLabel);
        
        selecaoZoomCB.setEditable(true);
        selecaoZoomCB.setModel(new javax.swing.DefaultComboBoxModel(
                new String[] { "10%", "20%", "30%", "40%", "50%", "60%", "70%", "80%",
                "90%", "100%", "110%", "120%", "130%", "140%", "150%", "160%", "170%",
                "180%", "190%", "200%", "250%", "300%" }));
        selecaoZoomCB.setSelectedIndex(9);
        selecaoZoomCB.setMaximumSize(new java.awt.Dimension(80, 25));
        selecaoZoomCB.setMinimumSize(new java.awt.Dimension(80, 25));
        selecaoZoomCB.setPreferredSize(new java.awt.Dimension(80, 25));
        selecaoZoomCB.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                selecaoZoomCBActionPerformed(evt);
            }
        });
        
        jToolBar4.add(selecaoZoomCB);
        
        jLabel16.setText("  Equalizar: ");
        jLabel16.setMaximumSize(new java.awt.Dimension(65, 25));
        jLabel16.setMinimumSize(new java.awt.Dimension(65, 25));
        jLabel16.setPreferredSize(new java.awt.Dimension(65, 25));
        jToolBar4.add(jLabel16);
        
        jComboBox2.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Imagem", "Equaliza", "MiniMaxi", "Log", "Raiz", "Porcentagem" }));
        jComboBox2.setMaximumSize(new java.awt.Dimension(120, 25));
        jComboBox2.setMinimumSize(new java.awt.Dimension(120, 25));
        jComboBox2.setPreferredSize(new java.awt.Dimension(120, 25));
        jComboBox2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                aplicarEqualizacao((String) jComboBox2.getSelectedItem());
            }
        });
        
        jToolBar4.add(jComboBox2);
        jToolBar1.add(jToolBar4);
        getContentPane().add(jToolBar1, java.awt.BorderLayout.NORTH);
    }
    
    private void criarNucleoGUI() {
        jSplitPane1 = new JSplitPane();
        jToggleButton1 = new JToggleButton();
        jToggleButton2= new JToggleButton();
        jToggleButton3= new JToggleButton();
        jToggleButton4= new JToggleButton();
        jToggleButton5= new JToggleButton();
        jToggleButton6= new JToggleButton();
        jPanel5 = new JPanel();
        histogramaBtn= new JButton();
        jTabbedPane1 = new JTabbedPane();
        jTabbedPane2 = new JTabbedPane();
        tree1 = new JTree(top1);
        jProgressBar1 = new JProgressBar();
        jScrollPane_Arvore = new JScrollPane();
        
        jSplitPane1.setDividerLocation(200);
        jSplitPane1.setOneTouchExpandable(true);
        jPanel1.setLayout(null);
        
        tree1.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);
        tree1.setActionMap(new ActionMap());
        
        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                sairPrograma();
            }
        });
        
        tree1.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mousePressed(java.awt.event.MouseEvent evt) {
                if(evt.getButton() == evt.BUTTON1 && evt.getClickCount() == 2)
                    abrirArquivoArvore();
            }
        });
        
        jScrollPane_Arvore.setViewportView(tree1);
        jTabbedPane1.addTab("Diretrio",jScrollPane_Arvore);
        jTabbedPane1.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mousePressed(java.awt.event.MouseEvent evt) {
                if( evt.getClickCount() > 1){
                    if(jTabbedPane1.getSelectedIndex() == 0) {
                        top1.removeAllChildren();
                        montarArvore( System.getProperty("user.dir") , top1);
                        tree1.updateUI();
                    }
                }
            }
        });
        
        jSplitPane1.setLeftComponent(jTabbedPane1);
        
        jPanel5.setLayout(new java.awt.BorderLayout());
        
        jTabbedPane2.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mousePressed(java.awt.event.MouseEvent evt) {
                jTabbedPane2MousePressed(evt);
            }
        });
        jTabbedPane2.addContainerListener(new java.awt.event.ContainerAdapter() {
            public void componentAdded(java.awt.event.ContainerEvent evt) {
                jToolBar4.setVisible(true);
                jMenu2.setEnabled(true);
            }
        });
        
        jPanel5.add(jTabbedPane2, java.awt.BorderLayout.CENTER);
        
        jProgressBar1.setString(" ");
        jPanel5.add(jProgressBar1, java.awt.BorderLayout.SOUTH);
        
        jSplitPane1.setRightComponent(jPanel5);
        
        getContentPane().add(jSplitPane1, java.awt.BorderLayout.CENTER);
    }
    
    private void criarMenuBar() {
        jMenuBar1 = new JMenuBar();
        jMenu1 = new JMenu();
        jMenu2= new JMenu();
        jMenuZoom = new JMenu();
        jMenuEqualizar= new JMenu();
        jMenuOpcoes= new JMenu();
        jMenuConverter= new JMenu();
        jMenuAjuda= new JMenu();
        jMenuAbrir = new JMenuItem();
        jMenuSalvar = new JMenuItem();
        jMenuSalvarTodas = new JMenuItem();
        jMenuFechar= new JMenuItem();
        jMenuConfig= new JMenuItem();
        jSeparator1= new JSeparator();
        jSeparator5= new JSeparator();
        jSeparator4= new JSeparator();
        jMenuSair= new JMenuItem();
        jMenuHist= new JMenuItem();
        jMenuZoomN= new JMenuItem();
        jMenuZoomIn= new JMenuItem();
        jMenuZoomOut= new JMenuItem();
        jMenuOriginal= new JMenuItem();
        jMenuEqualiza=new JMenuItem();
        jMenuMiniMaxi= new JMenuItem();
        jMenuLog= new JMenuItem();
        jMenuRaiz= new JMenuItem();
        jMenuPorcentagem= new JMenuItem();
        jMenuRGB2HLS= new JMenuItem();
        jMenuRGB2IHS= new JMenuItem();
        jMenuHLS2RGB= new JMenuItem();
        jMenuIHS2RGB= new JMenuItem();
        jMenuFalsaCor= new JMenuItem();
        jMenuFusao= new JMenuItem();
        jMenuTutorial= new JMenuItem();
        jMenuSobre= new JMenuItem();
        
        jMenu1.setMnemonic('A');
        jMenu1.setText("Arquivo");
        jMenu1.setToolTipText("Arquivo");
        jMenuAbrir.setIcon(new javax.swing.ImageIcon("src/folder_picture.png"));
        jMenuAbrir.setMnemonic('A');
        jMenuAbrir.setText("Abrir Imagem");
        jMenuAbrir.setToolTipText("Abrir Imagem");
        jMenuAbrir.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                abrirImagemAba();
            }
        });
        
        jMenu1.add(jMenuAbrir);
        
        jMenuSalvar.setIcon(new javax.swing.ImageIcon("src//disk.png"));
        jMenuSalvar.setMnemonic('S');
        jMenuSalvar.setText("Salvar Imagem");
        jMenuSalvar.setToolTipText("Salvar Imagem");
        jMenuSalvar.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                salvarImagem();
            }
        });
        
        jMenu1.add(jMenuSalvar);
        
        jMenuSalvarTodas.setIcon(new javax.swing.ImageIcon("src//disk_multiple.png"));
        jMenuSalvarTodas.setMnemonic('T');
        jMenuSalvarTodas.setText("Salvar Tudo");
        jMenuSalvarTodas.setToolTipText("Salvar Tudo");
        jMenuSalvarTodas.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                salvarTudo();
            }
        });
        
        jMenu1.add(jMenuSalvarTodas);
        
        jMenuFechar.setIcon(new javax.swing.ImageIcon("src//cross.png"));
        jMenuFechar.setMnemonic('F');
        jMenuFechar.setText("Fechar Imagem");
        jMenuFechar.setToolTipText("Fechar Imagem");
        jMenuFechar.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fecharItem();
            }
        });
        
        jMenu1.add(jMenuFechar);
        
        jMenu1.add(jSeparator4);
        
        jMenuConfig.setIcon(new javax.swing.ImageIcon("src//cog.png"));
        jMenuConfig.setMnemonic('C');
        jMenuConfig.setText("Configura\u00e7\u00f5es");
        jMenuConfig.setToolTipText("Configura\u00e7\u00f5es");
        jMenuConfig.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cfg.setVisible(true);
            }
        });
        
        jMenu1.add(jMenuConfig);
        
        jMenu1.add(jSeparator1);
        
        jMenuSair.setIcon(new javax.swing.ImageIcon("src//cancel.png"));
        jMenuSair.setMnemonic('X');
        jMenuSair.setText("Sair do Programa");
        jMenuSair.setToolTipText("Sair do Programa");
        jMenuSair.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                sairPrograma();
            }
        });
        
        jMenu1.add(jMenuSair);
        
        jMenuBar1.add(jMenu1);
        
        jMenu2.setMnemonic('F');
        jMenu2.setText("Ferramentas");
        jMenu2.setToolTipText("Ferramentas");
        jMenuHist.setIcon(new javax.swing.ImageIcon("src//chart_bar.png"));
        jMenuHist.setMnemonic('H');
        jMenuHist.setText("Gerar Histograma");
        jMenuHist.setToolTipText("Gerar Histograma");
        jMenuHist.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                criarHistograma();
            }
        });
        
        jMenu2.add(jMenuHist);
        
        jMenu2.add(jSeparator5);
        
        jMenuZoom.setIcon(new javax.swing.ImageIcon("src//magnifier.png"));
        jMenuZoom.setMnemonic('Z');
        jMenuZoom.setText("Zoom Imagem");
        jMenuZoom.setToolTipText("Zoom Imagem");
        jMenuZoomN.setIcon(new javax.swing.ImageIcon("src//zoom.png"));
        jMenuZoomN.setMnemonic('N');
        jMenuZoomN.setText("Zoom Normal (100%)");
        jMenuZoomN.setToolTipText("Zoom Normal (100%)");
        jMenuZoomN.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomImagem( 0, 1.00f);
            }
        });
        
        jMenuZoom.add(jMenuZoomN);
        
        jMenuZoomIn.setIcon(new javax.swing.ImageIcon("src//zoom_in.png"));
        jMenuZoomIn.setMnemonic('I');
        jMenuZoomIn.setText("Zoom In (+10%)");
        jMenuZoomIn.setToolTipText("Zoom In (+10%)");
        jMenuZoomIn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomImagem( 1, 0.10f);
            }
        });
        
        jMenuZoom.add(jMenuZoomIn);
        
        jMenuZoomOut.setIcon(new javax.swing.ImageIcon("src//zoom_out.png"));
        jMenuZoomOut.setMnemonic('O');
        jMenuZoomOut.setText("Zoom Out (-10%)");
        jMenuZoomOut.setToolTipText("Zoom Out (-10%)");
        jMenuZoomOut.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomImagem( -1, 0.10f);
            }
        });
        
        jMenuZoom.add(jMenuZoomOut);
        
        jMenu2.add(jMenuZoom);
        
        jMenuEqualizar.setIcon(new javax.swing.ImageIcon("src//pictures.png"));
        jMenuEqualizar.setMnemonic('E');
        jMenuEqualizar.setText("Equalizar Imagem");
        jMenuEqualizar.setToolTipText("Equalizar Imagem");
        jMenuOriginal.setMnemonic('G');
        jMenuOriginal.setText("Imagem Original");
        jMenuOriginal.setToolTipText("Imagem Original");
        jMenuOriginal.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox2.setSelectedItem("Imagem");
            }
        });
        
        jMenuEqualizar.add(jMenuOriginal);
        
        jMenuEqualiza.setMnemonic('Q');
        jMenuEqualiza.setText("Equaliza");
        jMenuEqualiza.setToolTipText("Equaliza");
        jMenuEqualiza.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox2.setSelectedItem("Equaliza");
            }
        });
        
        jMenuEqualizar.add(jMenuEqualiza);
        
        jMenuMiniMaxi.setMnemonic('M');
        jMenuMiniMaxi.setText("MiniMaxi");
        jMenuMiniMaxi.setToolTipText("MiniMaxi");
        jMenuMiniMaxi.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox2.setSelectedItem("MiniMaxi");
            }
        });
        
        jMenuEqualizar.add(jMenuMiniMaxi);
        
        jMenuLog.setMnemonic('L');
        jMenuLog.setText("Log");
        jMenuLog.setToolTipText("Log");
        jMenuLog.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox2.setSelectedItem("Log");
            }
        });
        
        jMenuEqualizar.add(jMenuLog);
        
        jMenuRaiz.setMnemonic('R');
        jMenuRaiz.setText("Raiz");
        jMenuRaiz.setToolTipText("Raiz");
        jMenuRaiz.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox2.setSelectedItem("Raiz");
            }
        });
        
        jMenuEqualizar.add(jMenuRaiz);
        
        jMenuPorcentagem.setMnemonic('P');
        jMenuPorcentagem.setText("Porcentagem");
        jMenuPorcentagem.setToolTipText("Porcentagem");
        jMenuPorcentagem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox2.setSelectedItem("Porcentagem");
            }
        });
        
        jMenuEqualizar.add(jMenuPorcentagem);
        
        jMenu2.add(jMenuEqualizar);
        
        jMenuBar1.add(jMenu2);
        
        jMenuOpcoes.setMnemonic('O');
        jMenuOpcoes.setText("Opes");
        jMenuOpcoes.setToolTipText("Opes");
        
        jMenuConverter.setIcon(new javax.swing.ImageIcon("src//control_fastforward_blue.png"));
        jMenuConverter.setMnemonic('C');
        jMenuConverter.setText("Converter");
        jMenuConverter.setToolTipText("Opes de Converso");
        jMenuOpcoes.add(jMenuConverter);
        
        jMenuRGB2HLS.setMnemonic('R');
        jMenuRGB2HLS.setText("RGB para HLS");
        jMenuRGB2HLS.setToolTipText("Converte RGB para HLS");
        jMenuRGB2HLS.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jTabbedPane1.addTab("Op\u00e7\u00f5es", jPanel1);
                jTabbedPane1.setSelectedComponent(jPanel1);
                selecionarRGB2HLS();
            }
        });
        jMenuConverter.add(jMenuRGB2HLS);
        
        jMenuRGB2IHS.setMnemonic('R');
        jMenuRGB2IHS.setText("RBG para IHS");
        jMenuRGB2IHS.setToolTipText("Converte RGB para IHS");
        jMenuRGB2IHS.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jTabbedPane1.addTab("Op\u00e7\u00f5es", jPanel1);
                jTabbedPane1.setSelectedComponent(jPanel1);
                selecionarRGB2IHS();
            }
        });
        jMenuConverter.add(jMenuRGB2IHS);
        
        jMenuHLS2RGB.setMnemonic('H');
        jMenuHLS2RGB.setText("HLS para RGB");
        jMenuHLS2RGB.setToolTipText("Converte HLS para RGB");
        jMenuHLS2RGB.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jTabbedPane1.addTab("Op\u00e7\u00f5es", jPanel1);
                jTabbedPane1.setSelectedComponent(jPanel1);
                selecionarHLS2RGB();
            }
        });
        jMenuConverter.add(jMenuHLS2RGB);
        
        jMenuIHS2RGB.setMnemonic('I');
        jMenuIHS2RGB.setText("IHS para RGB");
        jMenuIHS2RGB.setToolTipText("Converte IHS para RGB");
        jMenuIHS2RGB.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jTabbedPane1.addTab("Op\u00e7\u00f5es", jPanel1);
                jTabbedPane1.setSelectedComponent(jPanel1);
                selecionarIHS2RGB();
            }
        });
        jMenuConverter.add(jMenuIHS2RGB);
        
        
        jMenuFalsaCor.setIcon(new javax.swing.ImageIcon("src//color_swatch.png"));
        jMenuFalsaCor.setMnemonic('F');
        jMenuFalsaCor.setText("Gerar Falsa Cor");
        jMenuFalsaCor.setToolTipText("Gerar Falsa Cor");
        jMenuFalsaCor.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jTabbedPane1.addTab("Op\u00e7\u00f5es", jPanel1);
                jTabbedPane1.setSelectedComponent(jPanel1);
                selecionarFalsaCor();
            }
        });
        jMenuOpcoes.add(jMenuFalsaCor);
        
        
        jMenuFusao.setIcon(new javax.swing.ImageIcon("src//images.png"));
        jMenuFusao.setMnemonic('F');
        jMenuFusao.setText("Gerar Fuso");
        jMenuFusao.setToolTipText("Gerar Fuso");
        jMenuFusao.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jTabbedPane1.addTab("Op\u00e7\u00f5es", jPanel1);
                jTabbedPane1.setSelectedComponent(jPanel1);
                selecionarFusao();
            }
        });
        jMenuOpcoes.add(jMenuFusao);
        
        
        jMenuBar1.add(jMenuOpcoes);
        
       /* jMenuAjuda.setMnemonic('j');
        jMenuAjuda.setText("Ajuda");
        jMenuAjuda.setToolTipText("Ajuda");
        jMenuTutorial.setIcon(new javax.swing.ImageIcon("src//book_open.png"));
        jMenuTutorial.setMnemonic('T');
        jMenuTutorial.setText("Tutorial de Ajuda");
        jMenuTutorial.setToolTipText("Tutorial de Ajuda");
        jMenuAjuda.add(jMenuTutorial);
        
        jMenuSobre.setIcon(new javax.swing.ImageIcon("src//vcard_edit.png"));
        jMenuSobre.setMnemonic('b');
        jMenuSobre.setText("Sobre");
        jMenuSobre.setToolTipText("Sobre");
        jMenuAjuda.add(jMenuSobre);
        
        jMenuBar1.add(jMenuAjuda);*/
        
        setJMenuBar(jMenuBar1);
    }
    
    private void initComponents() {
        jPanel1 = new JPanel();
        buttonGroup1 = new ButtonGroup();
        jPanel1 = new javax.swing.JPanel();
        jPanelRGB2IHS = new javax.swing.JPanel();
        jPanelHLS2RGB = new javax.swing.JPanel();
        jPanelIHS2RGB = new javax.swing.JPanel();
        jPanelFalsaCor = new javax.swing.JPanel();
        jPanelFusao = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        jLabel9 = new javax.swing.JLabel();
        jLabel10 = new javax.swing.JLabel();
        jLabel11 = new javax.swing.JLabel();
        jLabel12 = new javax.swing.JLabel();
        jLabel13 = new javax.swing.JLabel();
        jLabel14 = new javax.swing.JLabel();
        jLabel16 = new javax.swing.JLabel();
        jLabel15 = new javax.swing.JLabel();
        jLabel18 = new javax.swing.JLabel();
        jTextField1 = new javax.swing.JTextField();
        jTextField2 = new javax.swing.JTextField();
        jTextField3 = new javax.swing.JTextField();
        jTextField_1 = new javax.swing.JTextField();
        jTextField_2 = new javax.swing.JTextField();
        jTextField_3 = new javax.swing.JTextField();
        jTextField4 = new javax.swing.JTextField();
        jTextField5 = new javax.swing.JTextField();
        jTextField6 = new javax.swing.JTextField();
        jTextField7 = new javax.swing.JTextField();
        jTextField8 = new javax.swing.JTextField();
        jTextField9 = new javax.swing.JTextField();
        jTextField10 = new javax.swing.JTextField();
        jTextField11 = new javax.swing.JTextField();
        jTextField12 = new javax.swing.JTextField();
        jTextField16 = new javax.swing.JTextField();
        jTextField15 = new javax.swing.JTextField();
        jTextField17 = new javax.swing.JTextField();
        jButton_5 = new javax.swing.JButton();
        jButton_4 = new javax.swing.JButton();
        jButton_3 = new javax.swing.JButton();
        jButton5 = new javax.swing.JButton();
        jButton4 = new javax.swing.JButton();
        jButton3 = new javax.swing.JButton();
        jButton7 = new javax.swing.JButton();
        jButton8 = new javax.swing.JButton();
        jButton9 = new javax.swing.JButton();
        jButton10 = new javax.swing.JButton();
        jButton11 = new javax.swing.JButton();
        jButton12 = new javax.swing.JButton();
        jButton14 = new javax.swing.JButton();
        jButton15 = new javax.swing.JButton();
        jButton16 = new javax.swing.JButton();
        jButton22 = new javax.swing.JButton();
        jButton23 = new javax.swing.JButton();
        jButton24 = new javax.swing.JButton();
        
        jPopupMenu1 = new javax.swing.JPopupMenu();
        jMenuItem4 = new javax.swing.JMenuItem();
        jSeparator2 = new javax.swing.JSeparator();
        jCheckBoxMenuItem1 = new javax.swing.JCheckBoxMenuItem();
        jCheckBoxMenuItem2 = new javax.swing.JCheckBoxMenuItem();
        jCheckBoxMenuItem3 = new javax.swing.JCheckBoxMenuItem();
        
        jPopupMenu2 = new javax.swing.JPopupMenu();
        jMenuItem6 = new javax.swing.JMenuItem();
        jMenuItem5 = new javax.swing.JMenuItem();
        jSeparator3 = new javax.swing.JSeparator();
        jMenuItem7 = new javax.swing.JMenuItem();
        
        
        // Cria o painel de conversao de RGB para HLS
        jPanelRGB2HLS = new javax.swing.JPanel();
        jPanelRGB2HLS.setLayout(null);
        jPanelRGB2HLS.setBorder(javax.swing.BorderFactory.createTitledBorder("Converter RGB para HLS"));
        JLabel jLabel_RGB2HLS_R = new JLabel("R:");
        JLabel jLabel_RGB2HLS_G = new JLabel("G:");
        JLabel jLabel_RGB2HLS_B = new JLabel("B:");
        jLabel_RGB2HLS_R.setBounds(10, 20, 20, 20);
        jLabel_RGB2HLS_G.setBounds(10, 50, 20, 20);
        jLabel_RGB2HLS_B.setBounds(10, 80, 20, 20);
        jPanelRGB2HLS.add(jLabel_RGB2HLS_R);
        jPanelRGB2HLS.add(jLabel_RGB2HLS_G);
        jPanelRGB2HLS.add(jLabel_RGB2HLS_B);
        jTextField1.setEditable(false);
        jTextField2.setEditable(false);
        jTextField3.setEditable(false);
        jTextField1.setBounds(30, 20, 110, 20);
        jTextField2.setBounds(30, 50, 110, 20);
        jTextField3.setBounds(30, 80, 110, 20);
        jPanelRGB2HLS.add(jTextField1);
        jPanelRGB2HLS.add(jTextField2);
        jPanelRGB2HLS.add(jTextField3);
        
        jButton5.setText("...");
        jButton5.setFocusPainted(false);
        jButton5.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgBlue = abreImagem();
                if(fileImgBlue!=null)jTextField3.setText(fileImgBlue.getName());
            }
        });
        
        jPanelRGB2HLS.add(jButton5);
        jButton5.setBounds(140, 80, 20, 19);
        
        jButton4.setText("...");
        jButton4.setFocusPainted(false);
        jButton4.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgGreen = abreImagem();
                if(fileImgGreen!=null)jTextField2.setText(fileImgGreen.getName());
            }
        });
        
        jPanelRGB2HLS.add(jButton4);
        jButton4.setBounds(140, 50, 20, 19);
        
        jButton3.setText("...");
        jButton3.setFocusPainted(false);
        jButton3.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgRed = abreImagem();
                if(fileImgRed!=null) jTextField1.setText(fileImgRed.getName());
            }
        });
        
        jPanelRGB2HLS.add(jButton3);
        jButton3.setBounds(140, 20, 20, 19);
        
        converterRGB2HLS = new JButton();
        converterRGB2HLS.setText("Converter");
        converterRGB2HLS.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cRGB2HLS();
            }
        });
        
        jPanelRGB2HLS.add(converterRGB2HLS);
        converterRGB2HLS.setBounds(10, 110, 150, 23);
        
        jPanelRGB2HLS.setBounds(10,20,175,145);
        jPanelRGB2HLS.setVisible(false);
        jPanel1.add(jPanelRGB2HLS);
        
        
        // Cria o painel de conversao de RGB para IHS
        jPanelRGB2IHS = new javax.swing.JPanel();
        jPanelRGB2IHS.setLayout(null);
        jPanelRGB2IHS.setBorder(javax.swing.BorderFactory.createTitledBorder("Converter RGB para IHS"));
        
        JLabel jLabel_RGB2IHS_R = new JLabel("R:");
        JLabel jLabel_RGB2IHS_G = new JLabel("G:");
        JLabel jLabel_RGB2IHS_B = new JLabel("B:");
        jLabel_RGB2IHS_R.setBounds(10, 20, 20, 20);
        jLabel_RGB2IHS_G.setBounds(10, 50, 20, 20);
        jLabel_RGB2IHS_B.setBounds(10, 80, 20, 20);
        jPanelRGB2IHS.add(jLabel_RGB2IHS_R);
        jPanelRGB2IHS.add(jLabel_RGB2IHS_G);
        jPanelRGB2IHS.add(jLabel_RGB2IHS_B);
        jTextField_1.setEditable(false);
        jTextField_2.setEditable(false);
        jTextField_3.setEditable(false);
        jTextField_1.setBounds(30, 20, 110, 20);
        jTextField_2.setBounds(30, 50, 110, 20);
        jTextField_3.setBounds(30, 80, 110, 20);
        jPanelRGB2IHS.add(jTextField_1);
        jPanelRGB2IHS.add(jTextField_2);
        jPanelRGB2IHS.add(jTextField_3);
        
        jButton_5.setText("...");
        jButton_5.setFocusPainted(false);
        jButton_5.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgBlue = abreImagem();
                if(fileImgBlue!=null)jTextField3.setText(fileImgBlue.getName());
            }
        });
        
        jPanelRGB2IHS.add(jButton_5);
        jButton_5.setBounds(140, 80, 20, 19);
        
        jButton_4.setText("...");
        jButton_4.setFocusPainted(false);
        jButton_4.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgGreen = abreImagem();
                if(fileImgGreen!=null)jTextField2.setText(fileImgGreen.getName());
            }
        });
        
        jPanelRGB2IHS.add(jButton_4);
        jButton_4.setBounds(140, 50, 20, 19);
        
        jButton_3.setText("...");
        jButton_3.setFocusPainted(false);
        jButton_3.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgRed = abreImagem();
                if(fileImgRed!=null) jTextField1.setText(fileImgRed.getName());
            }
        });
        
        jPanelRGB2IHS.add(jButton_3);
        jButton_3.setBounds(140, 20, 20, 19);
        
        converterRGB2IHS = new JButton();
        converterRGB2IHS.setText("Converter");
        converterRGB2IHS.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cRGB2IHS();
            }
        });
        
        jPanelRGB2IHS.add(converterRGB2IHS);
        converterRGB2IHS.setBounds(10, 110, 150, 23);
        
        jPanelRGB2IHS.setBounds(10,20,175,145);
        jPanelRGB2IHS.setVisible(false);
        jPanel1.add(jPanelRGB2IHS);
        
        
        // Converte HLS para RGB
        jPanelHLS2RGB.setLayout(null);
        jPanelHLS2RGB.setBorder(javax.swing.BorderFactory.createTitledBorder("Converter HLS para RGB"));
        
        JLabel jLabel_HLS2RGB_H = new JLabel("H:");
        JLabel jLabel_HLS2RGB_L = new JLabel("L:");
        JLabel jLabel_HLS2RGB_S = new JLabel("S:");
        jLabel_HLS2RGB_H.setBounds(10, 20, 20, 20);
        jLabel_HLS2RGB_L.setBounds(10, 50, 20, 20);
        jLabel_HLS2RGB_S.setBounds(10, 80, 20, 20);
        jPanelHLS2RGB.add(jLabel_HLS2RGB_L);
        jPanelHLS2RGB.add(jLabel_HLS2RGB_S);
        jPanelHLS2RGB.add(jLabel_HLS2RGB_H);
        jTextField4.setEditable(false);
        jTextField5.setEditable(false);
        jTextField6.setEditable(false);
        jTextField4.setBounds(30, 20, 110, 20);
        jTextField5.setBounds(30, 50, 110, 20);
        jTextField6.setBounds(30, 80, 110, 20);
        jPanelHLS2RGB.add(jTextField4);
        jPanelHLS2RGB.add(jTextField5);
        jPanelHLS2RGB.add(jTextField6);
        
        jButton7.setText("...");
        jButton7.setFocusPainted(false);
        jButton7.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgSaturation = abreImagem();
                if(fileImgSaturation!=null)jTextField6.setText(fileImgSaturation.getName());
            }
        });
        
        jPanelHLS2RGB.add(jButton7);
        jButton7.setBounds(140, 80, 20, 19);
        
        jButton8.setText("...");
        jButton8.setFocusPainted(false);
        jButton8.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgLightness = abreImagem();
                if(fileImgLightness!=null)jTextField5.setText(fileImgLightness.getName());
                
            }
        });
        
        jPanelHLS2RGB.add(jButton8);
        jButton8.setBounds(140, 50, 20, 19);
        
        jButton9.setText("...");
        jButton9.setFocusPainted(false);
        jButton9.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgHue = abreImagem();
                if(fileImgHue!=null)jTextField4.setText(fileImgHue.getName());
                
            }
        });
        
        jPanelHLS2RGB.add(jButton9);
        jButton9.setBounds(140, 20, 20, 19);
        
        converterHLS2RGB = new JButton();
        converterHLS2RGB.setText("Converter");
        converterHLS2RGB.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cHLS2RGB();
            }
        });
        
        jPanelHLS2RGB.add(converterHLS2RGB);
        converterHLS2RGB.setBounds(10, 110, 150, 23);
        
        jPanelHLS2RGB.setBounds(10,20,175,145);
        jPanelHLS2RGB.setVisible(false);
        jPanel1.add(jPanelHLS2RGB);
        
        
        // Converter IHS para RGB
        jPanelIHS2RGB.setLayout(null);
        jPanelIHS2RGB.setBorder(javax.swing.BorderFactory.createTitledBorder("Converter IHS para RGB"));
        
        JLabel jLabel_IHS2RGB_I = new JLabel("I:");
        JLabel jLabel_IHS2RGB_H = new JLabel("H:");
        JLabel jLabel_IHS2RGB_S = new JLabel("S:");
        jLabel_IHS2RGB_I.setBounds(10, 20, 20, 20);
        jLabel_IHS2RGB_H.setBounds(10, 50, 20, 20);
        jLabel_IHS2RGB_S.setBounds(10, 80, 20, 20);
        jPanelIHS2RGB.add(jLabel_IHS2RGB_I);
        jPanelIHS2RGB.add(jLabel_IHS2RGB_H);
        jPanelIHS2RGB.add(jLabel_IHS2RGB_S);
        jTextField7.setEditable(false);
        jTextField8.setEditable(false);
        jTextField9.setEditable(false);
        jTextField7.setBounds(30, 20, 110, 20);
        jTextField8.setBounds(30, 50, 110, 20);
        jTextField9.setBounds(30, 80, 110, 20);
        jPanelIHS2RGB.add(jTextField7);
        jPanelIHS2RGB.add(jTextField8);
        jPanelIHS2RGB.add(jTextField9);
        
        jButton10.setText("...");
        jButton10.setFocusPainted(false);
        jButton10.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgSaturation = abreImagem();
                if(fileImgSaturation!=null)jTextField9.setText(fileImgSaturation.getName());
            }
        });
        
        jPanelIHS2RGB.add(jButton10);
        jButton10.setBounds(140, 80, 20, 19);
        
        jButton11.setText("...");
        jButton11.setFocusPainted(false);
        jButton11.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgHue = abreImagem();
                if(fileImgHue!=null)jTextField8.setText(fileImgHue.getName());
                
            }
        });
        
        jPanelIHS2RGB.add(jButton11);
        jButton11.setBounds(140, 50, 20, 19);
        
        jButton12.setText("...");
        jButton12.setFocusPainted(false);
        jButton12.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgIntensity = abreImagem();
                if(fileImgIntensity!=null)jTextField7.setText(fileImgIntensity.getName());
            }
        });
        
        jPanelIHS2RGB.add(jButton12);
        jButton12.setBounds(140, 20, 20, 19);
        
        converterIHS2RGB = new JButton();
        converterIHS2RGB.setText("Converter");
        converterIHS2RGB.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cIHS2RGB();
            }
        });
        
        jPanelIHS2RGB.add(converterIHS2RGB);
        converterIHS2RGB.setBounds(10, 110, 150, 23);
        
        jPanelIHS2RGB.setBounds(10,20,175,145);
        jPanelIHS2RGB.setVisible(false);
        jPanel1.add(jPanelIHS2RGB);
        
        // Gera o falsa cor
        jPanelFalsaCor.setLayout(null);
        jPanelFalsaCor.setBorder(javax.swing.BorderFactory.createTitledBorder("Falsa Cor"));
        
        JLabel jLabel_FalsaCor_1 = new JLabel("B1:");
        JLabel jLabel_FalsaCor_2 = new JLabel("B2:");
        JLabel jLabel_FalsaCor_3 = new JLabel("B3:");
        jLabel_FalsaCor_1.setBounds(10, 20, 20, 20);
        jLabel_FalsaCor_2.setBounds(10, 50, 20, 20);
        jLabel_FalsaCor_3.setBounds(10, 80, 20, 20);
        jPanelFalsaCor.add(jLabel_FalsaCor_1);
        jPanelFalsaCor.add(jLabel_FalsaCor_2);
        jPanelFalsaCor.add(jLabel_FalsaCor_3);
        jTextField10.setEditable(false);
        jTextField11.setEditable(false);
        jTextField12.setEditable(false);
        jTextField10.setBounds(30, 20, 110, 20);
        jTextField11.setBounds(30, 50, 110, 20);
        jTextField12.setBounds(30, 80, 110, 20);
        jPanelFalsaCor.add(jTextField10);
        jPanelFalsaCor.add(jTextField11);
        jPanelFalsaCor.add(jTextField12);
        
        jButton14.setText("...");
        jButton14.setFocusPainted(false);
        jButton14.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgBanda3 = abreImagem();
                if(fileImgBanda3!=null) jTextField12.setText(fileImgBanda3.getName());
            }
        });
        
        jPanelFalsaCor.add(jButton14);
        jButton14.setBounds(140, 80, 20, 19);
        
        jButton15.setText("...");
        jButton15.setFocusPainted(false);
        jButton15.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgBanda2 = abreImagem();
                if(fileImgBanda2!=null) jTextField11.setText(fileImgBanda2.getName());
            }
        });
        
        jPanelFalsaCor.add(jButton15);
        jButton15.setBounds(140, 50, 20, 19);
        
        jButton16.setText("...");
        jButton16.setFocusPainted(false);
        jButton16.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgBanda1 = abreImagem();
                if(fileImgBanda1!=null) jTextField10.setText(fileImgBanda1.getName());
            }
        });
        
        jPanelFalsaCor.add(jButton16);
        jButton16.setBounds(140, 20, 20, 19);
        
        
        falsaCorBtn = new JButton();
        falsaCorBtn.setText("Criar Falsa Cor");
        falsaCorBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                falsaCorBtnActionPerformed(evt);
            }
        });
        
        jPanelFalsaCor.add(falsaCorBtn);
        falsaCorBtn.setBounds(10, 110, 150, 23);
        
        jPanelFalsaCor.setBounds(10,20,175,145);
        jPanelFalsaCor.setVisible(false);
        jPanel1.add(jPanelFalsaCor);
        
        
        jPanelFusao.setLayout(null);
        
        jPanelFusao.setBorder(javax.swing.BorderFactory.createTitledBorder("Fus\u00e3o"));
        jTextField15.setEditable(false);
        jPanelFusao.add(jTextField15);
        jTextField15.setBounds(30, 20, 110, 20);
        
        jLabel14.setText("P:");
        jPanelFusao.add(jLabel14);
        jLabel14.setBounds(10, 20, 20, 20);
        
        jLabel15.setText("H:");
        jPanelFusao.add(jLabel15);
        jLabel15.setBounds(10, 50, 20, 20);
        
        jTextField16.setEditable(false);
        jPanelFusao.add(jTextField16);
        jTextField16.setBounds(30, 50, 110, 20);
        
        jLabel18.setText("S:");
        jPanelFusao.add(jLabel18);
        jLabel18.setBounds(10, 80, 20, 20);
        
        jTextField17.setEditable(false);
        jPanelFusao.add(jTextField17);
        jTextField17.setBounds(30, 80, 110, 20);
        
        jButton22.setText("...");
        jButton22.setFocusPainted(false);
        jButton22.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgSaturation = abreImagem();
                if(fileImgSaturation!=null) jTextField17.setText(fileImgSaturation.getName());
            }
        });
        
        jPanelFusao.add(jButton22);
        jButton22.setBounds(140, 80, 20, 19);
        
        jButton23.setText("...");
        jButton23.setFocusPainted(false);
        jButton23.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgHue = abreImagem();
                if(fileImgHue!=null) jTextField16.setText(fileImgHue.getName());
            }
        });
        
        jPanelFusao.add(jButton23);
        jButton23.setBounds(140, 50, 20, 19);
        
        jButton24.setText("...");
        jButton24.setFocusPainted(false);
        jButton24.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fileImgPan = abreImagem();
                if(fileImgPan!=null) jTextField15.setText(fileImgPan.getName());
            }
        });
        
        jPanelFusao.add(jButton24);
        jButton24.setBounds(140, 20, 20, 19);
        
        fusaoBtn= new JButton();
        fusaoBtn.setText("Criar Fus\u00e3o");
        fusaoBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fusaoBtnActionPerformed(evt);
            }
        });
        jPanel1.add(fusaoBtn);
        fusaoBtn.setBounds(10, 500, 175, 23);
        
        jPanelFusao.add(fusaoBtn);
        fusaoBtn.setBounds(10, 110, 150, 23);
        
        jPanelFusao.setBounds(10,20,175,145);
        jPanelFusao.setVisible(false);
        jPanel1.add(jPanelFusao);
        
        
        jMenuItem4.setText("Item");
        jPopupMenu1.add(jMenuItem4);
        
        jPopupMenu1.add(jSeparator2);
        
        jCheckBoxMenuItem1.setText("Banda #1");
        jCheckBoxMenuItem1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCheckBoxMenuItem1ActionPerformed(evt);
            }
        });
        
        jPopupMenu1.add(jCheckBoxMenuItem1);
        
        jCheckBoxMenuItem2.setText("Banda #2");
        jCheckBoxMenuItem2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCheckBoxMenuItem2ActionPerformed(evt);
            }
        });
        
        jPopupMenu1.add(jCheckBoxMenuItem2);
        
        jCheckBoxMenuItem3.setText("Banda #3");
        jCheckBoxMenuItem3.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCheckBoxMenuItem3ActionPerformed(evt);
            }
        });
        
        jPopupMenu1.add(jCheckBoxMenuItem3);
        
        jMenuItem6.setText("Abrir Imagem");
        jMenuItem6.setToolTipText("Abrir Imagem");
        jMenuItem6.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                abrirImagemAba();
            }
        });
        
        jPopupMenu2.add(jMenuItem6);
        
        jMenuItem5.setText("Salvar Imagem");
        jMenuItem5.setToolTipText("Salvar Imagem");
        jMenuItem5.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                salvarImagem();
            }
        });
        
        jPopupMenu2.add(jMenuItem5);
        
        jPopupMenu2.add(jSeparator3);
        
        jMenuItem7.setText("Fechar Imagem");
        jMenuItem7.setToolTipText("Fechar Imagem");
        jMenuItem7.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fecharItem();
            }
        });
        
        jPopupMenu2.add(jMenuItem7);
        
        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosed(java.awt.event.WindowEvent evt) {
                sairPrograma();
            }
        });
        
        criarToolBar();
        criarNucleoGUI();
        criarMenuBar();
                
        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        setBounds((screenSize.width-1000)/2, (screenSize.height-700)/2, 1000, 700);
    }
    
    
    private void selecaoZoomCBActionPerformed(java.awt.event.ActionEvent evt) {
        System.out.println("Ativo: "+ evt.getActionCommand());
        
        try {
            String selecionado = (String) selecaoZoomCB.getSelectedItem();
            if(selecionado.substring(selecionado.length()-1,selecionado.length()).equals("%")) {
                selecionado = selecionado.substring(0,selecionado.length()-1);
            }
            
            float fator = Float.parseFloat(selecionado)/100;
            
            System.out.println("Fator: "+fator);
            
            int tipo = 0;
            zoomImagem( tipo, fator);
            
        } catch (NumberFormatException ex) {
            System.out.println("NumberFormatException");
        } catch(IllegalArgumentException ex){
            System.out.println("IllegalArgumentException");
        } catch (StringIndexOutOfBoundsException ex) {
            System.out.println("StringIndexOutOfBoundsException");
        } catch (Exception ex) {
            System.out.println("EXCEPTION");
        }
    }
    
    
    // Tipo: 1 para zoom in, -1 para zoom out, 0 para tamanho original
    // Fator: fator de ampliaao ou reduo
    private void zoomImagem(int tipo_operacao, float fator) {
        
        Manipulador man = null;
        File arq = null;
        JTabbedPane pane = null;
        BufferedImage img = null;
        JScrollPane scrollImagem = null;
        
        int tipo_dado; // 1 para Manipulador , 2 para Vector de Manipulador
        
        try {
            man = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            arq = man.getArquivo();
            tipo_dado = 1;
        }catch (Exception ex) {
            Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            pane = (JTabbedPane) vect.get(0);
            man = (Manipulador) vect.get(pane.getSelectedIndex()+1);
            arq = man.getArquivo();
            tipo_dado = 2;
            
            System.out.println("Indice Alto: "+ jTabbedPane2.getSelectedIndex());
            System.out.println("Indice Baixo: "+ pane.getSelectedIndex());
        }
        
        // Ampliao
        if(tipo_operacao == 1 || tipo_operacao == -1) {
            //float novo_fator =
            img = JAIZoom.Zoom(arq.getPath(), man.getPerc_zoom()+fator*tipo_operacao ,man.getPerc_zoom()+fator*tipo_operacao, cfg.getMetodoSelecionado());
            man.setPerc_zoom(man.getPerc_zoom()+fator*tipo_operacao);
        } else if (tipo_operacao == 0) {
            img = JAIZoom.Zoom(arq.getPath(),  fator , fator , cfg.getMetodoSelecionado());
            man.setPerc_zoom(fator);
        }
        
        System.out.println("Zoom >>"+ man.getPerc_zoom());

        
        if(tipo_dado == 1) {
            scrollImagem = (JScrollPane) jTabbedPane2.getSelectedComponent();
        } else if(tipo_dado == 2) {
            scrollImagem = (JScrollPane) pane.getSelectedComponent();
        }
        
        Equaliza eq = new Equaliza(img);
        img = eq.aplicarMetodo((String) jComboBox2.getSelectedItem());
        if(img == null) return;
        
        
        
        JViewport viw = scrollImagem.getViewport();
        JLabel lab = new JLabel(new ImageIcon(img));
        scrollImagem.setViewportView(lab);
        scrollImagem.repaint();
    }
    
    private void jCheckBoxMenuItem3ActionPerformed(java.awt.event.ActionEvent evt) {
        Manipulador hand;
        String texto = "";
        try {
            hand = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            texto = jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex());
        } catch (Exception ex) {
            Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            JTabbedPane pane = (JTabbedPane) vect.get(0);
            hand = (Manipulador) vect.get(pane.getSelectedIndex()+1);
            texto = pane.getTitleAt(pane.getSelectedIndex());
            
            System.out.println("Texto: "+texto);
        }
        
        if(!opcaoSelecionada.equals("")) {
            atualizaCampoTexto(3, opcaoSelecionada, hand, texto);
        }
        
    }
    
    private void jCheckBoxMenuItem2ActionPerformed(java.awt.event.ActionEvent evt) {
        Manipulador hand;
        String texto = "";
        try {
            hand = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            texto = jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex());
        } catch (Exception ex) {
            Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            JTabbedPane pane = (JTabbedPane) vect.get(0);
            hand = (Manipulador) vect.get(pane.getSelectedIndex()+1);
            texto = pane.getTitleAt(pane.getSelectedIndex());
        }
        
        if(!opcaoSelecionada.equals("")) {
            atualizaCampoTexto(2, opcaoSelecionada , hand, texto);
        }
    }
    
    private void jCheckBoxMenuItem1ActionPerformed(java.awt.event.ActionEvent evt) {
        Manipulador hand;
        String texto = "";
        
        try {
            hand = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            texto = jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex());
        } catch (Exception ex) {
            Vector vect = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
            JTabbedPane pane = (JTabbedPane) vect.get(0);
            hand = (Manipulador) vect.get(pane.getSelectedIndex()+1);
            texto = pane.getTitleAt(pane.getSelectedIndex());
        }
        
        if(!opcaoSelecionada.equals("")) {
            atualizaCampoTexto(1, opcaoSelecionada, hand, texto);
        }
    }
    
    private void jTabbedPane2MousePressed(java.awt.event.MouseEvent evt) {
        
        if(evt.getButton() == evt.BUTTON3) {
            if(jTabbedPane2.getTabRunCount() < 1) return;
            
            if(!opcaoSelecionada.equals(""))
                jMenuItem4.setText(opcaoSelecionada);
            else {
                JOptionPane.showMessageDialog(this,"Selecione um mtodo","ERRO!",JOptionPane.PLAIN_MESSAGE);
                return;
            }
            
            try {
                Manipulador hand = (Manipulador) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                jPopupMenu1.show( evt.getComponent(), evt.getX(), evt.getY() );
            }catch (Exception e) {
                return;
            }
        } else if(evt.getButton() == evt.BUTTON2) {
            fecharItem();
        }
    }
    
    private void atualizaCampoTexto(int posicao, String botao, Manipulador hand, String texto) {
        System.out.println("Atualizar Texto");
        System.out.println("Botao Selecionado: "+ botao + " Index:" + jTabbedPane2.getSelectedIndex());
        System.out.println("Posicao"+ posicao);
        
        if(botao.equals("RGB2HLS")) {
            switch(posicao) {
                case 1:
                    jTextField1.setText(texto);
                    System.out.println(">>1" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgRed = hand.getArquivo();
                    
                    break;
                case 2:
                    jTextField2.setText(texto);
                    System.out.println(">>2" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgGreen = hand.getArquivo();
                    
                    break;
                case 3:
                    jTextField3.setText(texto);
                    System.out.println(">>3" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgBlue = hand.getArquivo();
                    
                    break;
            }
        } else if (botao.equals("RGB2IHS")) {
            switch(posicao) {
                case 1:
                    jTextField_1.setText(texto);
                    System.out.println(">>1" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgRed = hand.getArquivo();
                    
                    break;
                case 2:
                    jTextField_2.setText(texto);
                    System.out.println(">>2" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgGreen = hand.getArquivo();
                    
                    break;
                case 3:
                    jTextField_3.setText(texto);
                    System.out.println(">>3" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgBlue = hand.getArquivo();
                    
                    break;
            }
        } else if(botao.equals("HLS2RGB")) {
            switch(posicao) {
                case 1:
                    jTextField4.setText(texto);
                    System.out.println(">>1" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgHue = hand.getArquivo();
                    
                    break;
                case 2:
                    jTextField5.setText(texto);
                    System.out.println(">>2" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgLightness = hand.getArquivo();
                    
                    break;
                case 3:
                    jTextField6.setText(texto);
                    System.out.println(">>3" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgSaturation = hand.getArquivo();
                    
                    break;
            }
        } else if(botao.equals("IHS2RGB")) {
            switch(posicao) {
                case 1:
                    jTextField7.setText(texto);
                    System.out.println(">>1" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgIntensity = hand.getArquivo();
                    
                    break;
                case 2:
                    jTextField8.setText(texto);
                    System.out.println(">>2" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgHue = hand.getArquivo();
                    
                    break;
                case 3:
                    jTextField9.setText(texto);
                    System.out.println(">>3" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgSaturation = hand.getArquivo();
                    
                    break;
            }
        } else if(botao.equals("FalsaCor")) {
            switch(posicao) {
                case 1:
                    jTextField10.setText(texto);
                    System.out.println(">>1" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgBanda1 = hand.getArquivo();
                    
                    break;
                case 2:
                    jTextField11.setText(texto);
                    System.out.println(">>2" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgBanda2 = hand.getArquivo();
                    
                    break;
                case 3:
                    jTextField12.setText(texto);
                    System.out.println(">>3" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgBanda3 = hand.getArquivo();
                    
                    break;
            }
        } else if(botao.equals("Fusao")) {
            switch(posicao) {
                case 1:
                    jTextField15.setText(texto);
                    System.out.println(">>1" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgPan = hand.getArquivo();
                    
                    break;
                case 2:
                    jTextField16.setText(texto);
                    System.out.println(">>2" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgHue = hand.getArquivo();
                    
                    break;
                case 3:
                    jTextField17.setText(texto);
                    System.out.println(">>3" + jTabbedPane2.getTitleAt(jTabbedPane2.getSelectedIndex()) );
                    fileImgSaturation = hand.getArquivo();
                    
                    break;
            }
        }
    }
    
    private void fusaoBtnActionPerformed(java.awt.event.ActionEvent evt) {
        if(fileImgPan != null && fileImgHue != null && fileImgSaturation != null) {
            System.out.println("Criando falsa Cor");
            
            Fusao tr = new Fusao(fileImgPan,fileImgHue,fileImgSaturation, cfg.getMetodoSelecionado(), jProgressBar1 );
            
            if(tr.isSucesso()){
                jTabbedPane2.add(tr);
                jTabbedPane2.setSelectedComponent(tr);
                
                jTabbedPane1.removeTabAt(1);
                jPanelFusao.setVisible(false);
                opcaoSelecionada = "";
                
                top1.removeAllChildren();
                montarArvore( System.getProperty("user.dir") , top1);
                tree1.updateUI();
                
                // Obtem o tabbedpane de dentro do tabbed principal para adicionar o listener
                Vector vecHand = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                JTabbedPane pane = (JTabbedPane) vecHand.get(0);
                pane.addMouseListener(this);
            }
        }
    }
    
    private void falsaCorBtnActionPerformed(java.awt.event.ActionEvent evt) {
        if(fileImgBanda1 != null && fileImgBanda2 != null && fileImgBanda3 != null) {
            System.out.println("Criando falsa Cor");
            
            FalsaCor falsa = new FalsaCor(fileImgBanda1, fileImgBanda2, fileImgBanda3 , cfg.getMetodoSelecionado(), jProgressBar1);
            
            if(falsa.isSucesso()){
                jTabbedPane2.add(falsa);
                jTabbedPane2.setSelectedComponent(falsa);
                
                jTabbedPane1.removeTabAt(1);
                jPanelFalsaCor.setVisible(false);
                opcaoSelecionada = "";
                
                top1.removeAllChildren();
                montarArvore( System.getProperty("user.dir") , top1);
                tree1.updateUI();
                
            }
        }
    }
    
    private void selecionarRGB2HLS() {
        if(jPanelRGB2HLS.isVisible()) {
            jTabbedPane1.remove(1);
            jPanelRGB2HLS.setVisible(false);
            opcaoSelecionada = "";
        } else {
            opcaoSelecionada = "RGB2HLS";
            
            jTextField1.setText("");
            jTextField2.setText("");
            jTextField3.setText("");
            fileImgRed = null;
            fileImgGreen = null;
            fileImgBlue = null;
            limpaCheckBox();
            
            jPanelRGB2HLS.setVisible(true);
            jPanelRGB2IHS.setVisible(false);
            jPanelHLS2RGB.setVisible(false);
            jPanelIHS2RGB.setVisible(false);
            jPanelFalsaCor.setVisible(false);
            jPanelFusao.setVisible(false);
        }
    }
    
    private void selecionarRGB2IHS() {
        if(jPanelRGB2IHS.isVisible()) {
            jTabbedPane1.remove(1);
            jPanelRGB2IHS.setVisible(false);
            opcaoSelecionada = "";
        } else {
            opcaoSelecionada = "RGB2IHS";
            
            jTextField_1.setText("");
            jTextField_2.setText("");
            jTextField_3.setText("");
            fileImgRed = null;
            fileImgGreen = null;
            fileImgBlue = null;
            limpaCheckBox();
            
            
            jPanelRGB2HLS.setVisible(false);
            jPanelRGB2IHS.setVisible(true);
            jPanelHLS2RGB.setVisible(false);
            jPanelIHS2RGB.setVisible(false);
            jPanelFalsaCor.setVisible(false);
            jPanelFusao.setVisible(false);
        }
    }
    
    private void selecionarHLS2RGB() {
        if(jPanelHLS2RGB.isVisible()) {
            jTabbedPane1.remove(1);
            jPanelHLS2RGB.setVisible(false);
            opcaoSelecionada = "";
        } else {
            opcaoSelecionada = "HLS2RGB";
            
            jTextField4.setText("");
            jTextField5.setText("");
            jTextField6.setText("");
            fileImgHue = null;
            fileImgLightness = null;
            fileImgSaturation = null;
            limpaCheckBox();
            
            
            jPanelRGB2HLS.setVisible(false);
            jPanelRGB2IHS.setVisible(false);
            jPanelHLS2RGB.setVisible(true);
            jPanelIHS2RGB.setVisible(false);
            jPanelFalsaCor.setVisible(false);
            jPanelFusao.setVisible(false);
        }
    }
    
    private void selecionarIHS2RGB() {
        if(jPanelIHS2RGB.isVisible()) {
            jTabbedPane1.remove(1);
            jPanelIHS2RGB.setVisible(false);
            opcaoSelecionada = "";
        } else {
            opcaoSelecionada = "IHS2RGB";
            
            jTextField7.setText("");
            jTextField8.setText("");
            jTextField9.setText("");
            fileImgIntensity = null;
            fileImgHue = null;
            fileImgSaturation = null;
            limpaCheckBox();
            
            
            jPanelRGB2HLS.setVisible(false);
            jPanelRGB2IHS.setVisible(false);
            jPanelHLS2RGB.setVisible(false);
            jPanelIHS2RGB.setVisible(true);
            jPanelFalsaCor.setVisible(false);
            jPanelFusao.setVisible(false);
        }
    }
    
    private void selecionarFalsaCor() {
        if(jPanelFalsaCor.isVisible()) {
            jTabbedPane1.remove(1);
            jPanelFalsaCor.setVisible(false);
            opcaoSelecionada = "";
        } else {
            opcaoSelecionada = "FalsaCor";
            jTextField10.setText("");
            jTextField11.setText("");
            jTextField12.setText("");
            fileImgBanda1 = null;
            fileImgBanda2 = null;
            fileImgBanda3 = null;
            limpaCheckBox();
            
            jPanelRGB2HLS.setVisible(false);
            jPanelRGB2IHS.setVisible(false);
            jPanelHLS2RGB.setVisible(false);
            jPanelIHS2RGB.setVisible(false);
            jPanelFalsaCor.setVisible(true);
            jPanelFusao.setVisible(false);
        }
    }
    
    private void selecionarFusao() {
        if(jPanelFusao.isVisible()) {
            jTabbedPane1.remove(1);
            jPanelFusao.setVisible(false);
            opcaoSelecionada = "";
        } else {
            opcaoSelecionada = "Fusao";
            
            jTextField15.setText("");
            jTextField16.setText("");
            jTextField17.setText("");
            fileImgPan = null;
            fileImgHue = null;
            fileImgSaturation = null;
            limpaCheckBox();
            
            jPanelRGB2HLS.setVisible(false);
            jPanelRGB2IHS.setVisible(false);
            jPanelHLS2RGB.setVisible(false);
            jPanelIHS2RGB.setVisible(false);
            jPanelFalsaCor.setVisible(false);
            jPanelFusao.setVisible(true);
        }
    }
    
    private void limpaCheckBox() {
        jCheckBoxMenuItem1.setSelected(false);
        jCheckBoxMenuItem2.setSelected(false);
        jCheckBoxMenuItem3.setSelected(false);
    }
    
    private void cIHS2RGB() {
        if(fileImgIntensity != null && fileImgHue != null && fileImgSaturation != null) {
            System.out.println("Convertendo Imagem RGB PARA IHS");
            
            IHS2RGB ihs_rgb = new IHS2RGB(fileImgIntensity, fileImgHue, fileImgSaturation,  cfg.getMetodoSelecionado(), jProgressBar1);
            
            if(ihs_rgb.isSucesso()){
                jTabbedPane2.add(ihs_rgb);
                jTabbedPane2.setSelectedComponent(ihs_rgb);
                
                jTabbedPane1.removeTabAt(1);
                jPanelIHS2RGB.setVisible(false);
                opcaoSelecionada = "";
                
                top1.removeAllChildren();
                montarArvore( System.getProperty("user.dir") , top1);
                tree1.updateUI();
                
                // Obtem o tabbedpane de dentro do tabbed principal para adicionar o listener
                Vector vecHand = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                JTabbedPane pane = (JTabbedPane) vecHand.get(0);
                pane.addMouseListener(this);
            }
        }
    }
    
    private void cHLS2RGB() {
        if(fileImgHue != null && fileImgLightness != null && fileImgSaturation != null) {
            System.out.println("Convertendo Imagem HLS PARA RGB");
            HLS2RGB hls_rgb = new HLS2RGB(fileImgHue, fileImgLightness, fileImgSaturation,  cfg.getMetodoSelecionado(), jProgressBar1);
            
            if(hls_rgb.isSucesso()){
                jTabbedPane2.add(hls_rgb);
                jTabbedPane2.setSelectedComponent(hls_rgb);
                
                jTabbedPane1.removeTabAt(1);
                jPanelHLS2RGB.setVisible(false);
                opcaoSelecionada = "";
                
                top1.removeAllChildren();
                montarArvore( System.getProperty("user.dir") , top1);
                tree1.updateUI();
                
                // Obtem o tabbedpane de dentro do tabbed principal para adicionar o listener
                Vector vecHand = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                JTabbedPane pane = (JTabbedPane) vecHand.get(0);
                pane.addMouseListener(this);
            }
        }
    }
    
    private void cRGB2IHS() {
        if(fileImgRed != null && fileImgBlue != null && fileImgGreen != null) {
            System.out.println("Convertendo Imagem RGB PARA IHS");
            RGB2IHS rgb_ihs = new RGB2IHS(fileImgRed, fileImgGreen, fileImgBlue, cfg.getMetodoSelecionado(), jProgressBar1);
            
            if(rgb_ihs.isSucesso()){
                jTabbedPane2.add(rgb_ihs);
                jTabbedPane2.setSelectedComponent(rgb_ihs);
                selecionarRGB2HLS();
                
                jTabbedPane1.removeTabAt(1);
                jPanelRGB2IHS.setVisible(false);
                opcaoSelecionada = "";
                
                top1.removeAllChildren();
                montarArvore( System.getProperty("user.dir") , top1);
                tree1.updateUI();
                
                // Obtem o tabbedpane de dentro do tabbed principal para adicionar o listener
                Vector vecHand = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                JTabbedPane pane = (JTabbedPane) vecHand.get(0);
                pane.addMouseListener(this);
                
            }
        }
    }
    
    private void cRGB2HLS() {
        jProgressBar1.setStringPainted(true);
        if(fileImgRed != null && fileImgBlue != null && fileImgGreen != null) {
            System.out.println("Convertendo Imagem RGB PARA HLS");
            
            RGB2HLS rgb_hls = new RGB2HLS(fileImgRed, fileImgGreen, fileImgBlue, cfg.getMetodoSelecionado(), jProgressBar1);
            
            if(rgb_hls.isSucesso()){
                jTabbedPane2.add(rgb_hls);
                jTabbedPane2.setSelectedComponent(rgb_hls);
                
                jTabbedPane1.removeTabAt(1);
                jPanelRGB2HLS.setVisible(false);
                opcaoSelecionada = "";
                
                top1.removeAllChildren();
                montarArvore( System.getProperty("user.dir") , top1);
                tree1.updateUI();
                
                // Obtem o tabbedpane de dentro do tabbed principal para adicionar o listener
                Vector vecHand = (Vector) imagensAbertas.get(jTabbedPane2.getSelectedIndex());
                JTabbedPane pane = (JTabbedPane) vecHand.get(0);
                pane.addMouseListener(this);
            }
        }
    }
    
    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new ColorSpaceGui().setVisible(true);
            }
        });
    }
    
    
    public void mouseClicked(MouseEvent e) {
    }
    
    public void mousePressed(MouseEvent evt) {
        
        Component comp = evt.getComponent();
        if(evt.getButton() == evt.BUTTON3) {
            String nomeComponent = comp.getName();
            if(nomeComponent==null) nomeComponent = "";
            if(nomeComponent.equals("ScrollImagem")) {
                jPopupMenu2.show( evt.getComponent(), evt.getX(), evt.getY() );
                
            } else {
                System.out.println("Entrou no envento Btn3");
                if(jTabbedPane2.getTabRunCount() < 1) return;
                
                if(!opcaoSelecionada.equals(""))
                    jMenuItem4.setText(opcaoSelecionada);
                else {
                    JOptionPane.showMessageDialog(this,"Selecione um mtodo","ERRO!",JOptionPane.PLAIN_MESSAGE);
                    return;
                }
                jPopupMenu1.show( evt.getComponent(), evt.getX(), evt.getY() );
                
            }
        }
    }
    
    public void mouseReleased(MouseEvent e) {
    }
    
    public void mouseEntered(MouseEvent e) {
    }
    
    public void mouseExited(MouseEvent e) {
    }
    
    // Declarao de variveis
    
    private JMenu jMenuConverter;
    private JMenuItem jMenuRGB2HLS;
    private JMenuItem jMenuRGB2IHS;
    private JMenuItem jMenuFalsaCor;
    private JMenuItem jMenuHLS2RGB;
    private JMenuItem jMenuIHS2RGB;
    private JMenuItem jMenuFusao;
    private javax.swing.JButton abreImgBtn;
    private javax.swing.ButtonGroup buttonGroup1;
    private javax.swing.ButtonGroup buttonGroup2;
    private javax.swing.JButton configZoomBtn;
    private javax.swing.JButton converterRGB2HLS;
    private javax.swing.JButton converterRGB2IHS;
    private javax.swing.JButton converterHLS2RGB;
    private javax.swing.JButton converterIHS2RGB;
    
    private javax.swing.JButton falsaCorBtn;
    private javax.swing.JLabel fatorLabel;
    private javax.swing.JButton fechaItemBtn;
    private javax.swing.JButton fusaoBtn;
    private javax.swing.JButton histogramaBtn;
    private javax.swing.JButton jButton10;
    private javax.swing.JButton jButton11;
    private javax.swing.JButton jButton12;
    private javax.swing.JButton jButton14;
    private javax.swing.JButton jButton15;
    private javax.swing.JButton jButton16;
    private javax.swing.JButton jButton22;
    private javax.swing.JButton jButton23;
    private javax.swing.JButton jButton24;
    private javax.swing.JButton jButton_3;
    private javax.swing.JButton jButton_4;
    private javax.swing.JButton jButton_5;
    private javax.swing.JButton jButton3;
    private javax.swing.JButton jButton4;
    private javax.swing.JButton jButton5;
    private javax.swing.JButton jButton7;
    private javax.swing.JButton jButton8;
    private javax.swing.JButton jButton9;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItem1;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItem2;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItem3;
    private javax.swing.JComboBox jComboBox2;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JMenu jMenu1;
    private javax.swing.JMenu jMenu2;
    private javax.swing.JMenuItem jMenuAbrir;
    private javax.swing.JMenu jMenuAjuda;
    private javax.swing.JMenuBar jMenuBar1;
    private javax.swing.JMenuItem jMenuConfig;
    private javax.swing.JMenuItem jMenuEqualiza;
    private javax.swing.JMenu jMenuEqualizar;
    private javax.swing.JMenuItem jMenuFechar;
    private javax.swing.JMenuItem jMenuHist;
    private javax.swing.JMenuItem jMenuItem4;
    private javax.swing.JMenuItem jMenuItem5;
    private javax.swing.JMenuItem jMenuItem6;
    private javax.swing.JMenuItem jMenuItem7;
    private javax.swing.JMenuItem jMenuLog;
    private javax.swing.JMenuItem jMenuMiniMaxi;
    private javax.swing.JMenuItem jMenuOpcoes;
    private javax.swing.JMenuItem jMenuOriginal;
    private javax.swing.JMenuItem jMenuPorcentagem;
    private javax.swing.JMenuItem jMenuRaiz;
    private javax.swing.JMenuItem jMenuSair;
    private javax.swing.JMenuItem jMenuSalvar;
    private javax.swing.JMenuItem jMenuSalvarTodas;
    private javax.swing.JMenuItem jMenuSobre;
    private javax.swing.JMenuItem jMenuTutorial;
    private javax.swing.JMenu jMenuZoom;
    private javax.swing.JMenuItem jMenuZoomIn;
    private javax.swing.JMenuItem jMenuZoomN;
    private javax.swing.JMenuItem jMenuZoomOut;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanelRGB2HLS;
    private javax.swing.JPanel jPanelRGB2IHS;
    private javax.swing.JPanel jPanelHLS2RGB;
    private javax.swing.JPanel jPanelIHS2RGB;
    private javax.swing.JPanel jPanel5;
    private javax.swing.JPanel jPanelFalsaCor;
    private javax.swing.JPanel jPanelFusao;
    private javax.swing.JPanel jPanel_Arvore;
    private javax.swing.JPopupMenu jPopupMenu1;
    private javax.swing.JPopupMenu jPopupMenu2;
    private javax.swing.JProgressBar jProgressBar1;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JSeparator jSeparator2;
    private javax.swing.JSeparator jSeparator3;
    private javax.swing.JSeparator jSeparator4;
    private javax.swing.JSeparator jSeparator5;
    private javax.swing.JScrollPane jScrollPane_Arvore;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JTabbedPane jTabbedPane2;
    private javax.swing.JTextField jTextField10;
    private javax.swing.JTextField jTextField11;
    private javax.swing.JTextField jTextField12;
    private javax.swing.JTextField jTextField15;
    private javax.swing.JTextField jTextField16;
    private javax.swing.JTextField jTextField17;
    private javax.swing.JTextField jTextField1;
    private javax.swing.JTextField jTextField2;
    private javax.swing.JTextField jTextField3;
    private javax.swing.JTextField jTextField_1;
    private javax.swing.JTextField jTextField_2;
    private javax.swing.JTextField jTextField_3;
    private javax.swing.JTextField jTextField4;
    private javax.swing.JTextField jTextField5;
    private javax.swing.JTextField jTextField6;
    private javax.swing.JTextField jTextField7;
    private javax.swing.JTextField jTextField8;
    private javax.swing.JTextField jTextField9;
    private javax.swing.JTree tree1;
    private javax.swing.JToggleButton jToggleButton1;
    private javax.swing.JToggleButton jToggleButton2;
    private javax.swing.JToggleButton jToggleButton3;
    private javax.swing.JToggleButton jToggleButton4;
    private javax.swing.JToggleButton jToggleButton5;
    private javax.swing.JToggleButton jToggleButton6;
    private javax.swing.JToolBar jToolBar1;
    private javax.swing.JToolBar jToolBar3;
    private javax.swing.JToolBar jToolBar4;
    private javax.swing.JButton salvarImgBtn;
    private javax.swing.JComboBox selecaoZoomCB;
    private javax.swing.JButton zoomInBtn;
    private javax.swing.JButton zoomNormalBtn;
    private javax.swing.JButton zoomOutBtn;
}

































