/*********************************************************************************
Equaliza.java - Implementa vrias transformaes no lineares e uma linear.

Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Implementa vrias transformaes no lineares e uma linear.

Parmetros de entrada:

    1. Arquivo de imagem.
    2. Metodo de equalizao.
 
Sada:
 
    Imagem equalizada conforme o metodo selecionado.

Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda

**********************************************************************************/

import java.io.File;

// pacotes do AWT
import java.awt.image.BufferedImage;
import java.awt.image.Raster;
import java.awt.image.WritableRaster;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.BorderLayout;
import java.awt.event.ItemListener;
import java.awt.event.ItemEvent;

// pacote Swing para interface grfica
import javax.swing.JFrame;
import javax.swing.JComponent;
import javax.swing.JComboBox;
import javax.swing.JPanel;

// leitura em modo imediato - para J2SE 1.4+
import javax.imageio.ImageIO;

public class Equaliza {
    
    // Define objeto BufferedImage para encapsular a imagem
    BufferedImage src = null;
    int w, h, hist[] = new int[256], max_hist = 0;
    
    public Equaliza(File file) {
        
        int nc;
        
        try {
            src = ImageIO.read(file);
        } catch (Exception e) {
            System.out.println("Erro lendo arquivo: " + file.getName());
            System.exit(0);
        }
        
        Raster srcR = src.getRaster();
        w = src.getWidth();
        h = src.getHeight();
        
        // Calcula histograma
        for (int i = 0; i < h; i++) {
            for (int j = 0; j < w; j++) {
                nc = srcR.getSample(j, i, 0);
                hist[nc]++;
            }
        }
        
        for (int i = 0; i < 256; i++) {
            if (hist[i] > max_hist)
                max_hist = hist[i];
        }
    }
    
    public Equaliza(BufferedImage img) {
        
        int nc;
        src = img;
        
        
        Raster srcR = src.getRaster();
        w = src.getWidth();
        h = src.getHeight();
        
        // Calcula histograma
        for (int i = 0; i < h; i++) {
            for (int j = 0; j < w; j++) {
                nc = srcR.getSample(j, i, 0);
                hist[nc]++;
            }
        }
        
        for (int i = 0; i < 256; i++) {
            if (hist[i] > max_hist)
                max_hist = hist[i];
        }
    }
        
    public BufferedImage aplicarMetodo(String opcao) {
        // super.paintComponent(gc);
        int nc, pixelOut;
        
        Raster srcR = src.getRaster();
        System.out.println("Metodo de equalizacao: "+opcao);
        // Transformao no linear - Equalizao de histograma
        //
        if (opcao.equals("Equaliza")) {
            int dim, histoEq[] = new int[256], tipo, fator;
            double soma = 0.0, normHisto[] = new double[256];
            
            tipo = BufferedImage.TYPE_BYTE_GRAY;
            BufferedImage eqlImage = new BufferedImage(w, h, tipo);
            WritableRaster eqlWR = eqlImage.getRaster();
            dim = w*h;
            for (int i = 0; i < 256; i++) {
                soma = 0.0;
                for (int j = 0; j <= i; j++) {
                    // se no usar o (double), valores = 0
                    soma += (double)hist[j]/dim;
                }
                histoEq[i] = (int)(255*soma + .5);
            }
            
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    pixelOut = histoEq[nc];
                    eqlWR.setSample(j, i, 0, pixelOut);
                }
            }
            return eqlImage;
        }
        
        // Transformao linear - mtodo mini-maxi
        //
        if (opcao.equals("MiniMaxi")) {
            double autoScale = 0.0;
            int grayMax = 255, grayMin = 0, sMin = 255, sMax = 0, tipo, fator;
            
            tipo = BufferedImage.TYPE_BYTE_GRAY;
            BufferedImage autoImage = new BufferedImage(w, h, tipo);
            WritableRaster autoWR = autoImage.getRaster();
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    sMax = Math.max(nc, sMax);
                    sMin = Math.min(nc, sMin);
                }
            }
            if ((sMax - sMin) != 0)
                autoScale = (double)(grayMax - grayMin)/(sMax - sMin);
            else
                autoScale = 1.0;
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    pixelOut = (int)(autoScale*(nc - sMin) + grayMin);
                    autoWR.setSample(j, i, 0, pixelOut);
                }
            }
            
            return autoImage;
        }
        
        // Transformao no linear - logaritmo
        //
        if (opcao.equals("Log")) {
            int grayMax = 255, grayMin = 0, fator, tipo;
            double val;
            
            tipo = BufferedImage.TYPE_BYTE_GRAY;
            BufferedImage logImage = new BufferedImage(w, h, tipo);
            WritableRaster logWR = logImage.getRaster();
            
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    val = 31.875*log2((double)(nc + 1));
                    pixelOut = (int)val;
                    if (pixelOut < grayMin)
                        pixelOut = grayMin;
                    else if (pixelOut > grayMax)
                        pixelOut = grayMax;
                    logWR.setSample(j, i, 0, pixelOut);
                }
            }
            return logImage;
        }
        
        // Transformao no linear - raiz quadrada
        //
        if (opcao.equals("Raiz")) {
            int grayMax = 255, grayMin = 0, tipo, fator;
            double val;
            
            tipo = BufferedImage.TYPE_BYTE_GRAY;
            BufferedImage raizImage = new BufferedImage(w, h, tipo);
            WritableRaster raizWR = raizImage.getRaster();
            
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    val = 16*Math.sqrt((double)(nc));
                    pixelOut = (int)val;
                    if (pixelOut < grayMin)
                        pixelOut = grayMin;
                    else if (pixelOut > grayMax)
                        pixelOut = grayMax;
                    raizWR.setSample(j, i, 0, pixelOut);
                }
            }
            
            return raizImage;
        }
        
        // Transformao no linear - porcentagem -1 e +1 desvio padro
        //
        if (opcao.equals("Porcentagem")) {
            int sMax = 0, sMin = 255, grayMax = 255, denom, tipo, fator;
            long total, sum, sum_sqr;
            double dSECOND, dVAR = 0.0, dMEAN, dDESVP, val;
            sum = sum_sqr = total = 0;
            
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    sMax = Math.max(nc, sMax);
                    sMin = Math.min(nc, sMin);
                    sum  += nc;
                    sum_sqr += nc*nc;
                    total++;
                }
            }
            dMEAN   = (double)sum/total;
            dSECOND = (double)sum_sqr/total;
            dVAR    = dSECOND - dMEAN*dMEAN;
            dDESVP  = Math.sqrt(dVAR);
            sMax = (int)(sMax - dDESVP);
            sMin = (int)(sMin + dDESVP);
            
            tipo = BufferedImage.TYPE_BYTE_GRAY;
            BufferedImage percentImage = new BufferedImage(w, h, tipo);
            WritableRaster percentWR = percentImage.getRaster();
            
            denom = sMax - sMin;
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    nc = srcR.getSample(j, i, 0);
                    if (nc < sMin)
                        nc = sMin;
                    else if (nc > sMax)
                        nc = sMax;
                    val = (double)grayMax*(nc - sMin)/denom;
                    pixelOut = (int)val;
                    percentWR.setSample(j, i, 0, pixelOut);
                }
            }
            
            return percentImage;
        }
        
        if (opcao.equals("Imagem")) {
            return src;
        }
        
        return null;
    }
    
    public static double log2(double parm) {
        return Math.log(parm)/Math.log(2.0);
    }
}
