/*********************************************************************************
Equaliza.java - Gera imagem sinttica em falsa cor.

Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Gera imagem sinttica em falsa cor

Parmetros de entrada:

    1. Trs bandas espectrais
 
Sada:
 
    Imagem colorida composta por trs bandas

Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda

**********************************************************************************/

import java.awt.GridLayout;
import java.io.File;
import java.io.IOException;
import java.awt.image.BufferedImage;
import java.awt.image.Raster;
import java.awt.image.WritableRaster;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ImageIcon;

// leitura em modo imediato - para J2SE 1.4+
import javax.imageio.ImageIO;
import javax.swing.JOptionPane;
import javax.swing.JProgressBar;

public class FalsaCor extends JScrollPane {
    
    private JProgressBar barraStatus;
    private boolean sucesso = false;
    
   private void updateBarra(String s, int n) {
        if(n%5 == 0) {
            barraStatus.setString(s);
            barraStatus.setValue(n);
            barraStatus.update(barraStatus.getGraphics());
        }
    }
        
    public static BufferedImage criaFalsa(BufferedImage src1,BufferedImage src2,BufferedImage src3) {
        
        BufferedImage dest;
        int nc1, nc2, nc3, w, h, tipo;
        int w1, w2, w3, h1, h2, h3;
        // Certifica que as imagens existem
        
        // Acha as dimenses das imagens...
        w1 = src1.getWidth();
        h1 = src1.getHeight();
        w2 = src2.getWidth();
        h2 = src2.getHeight();
        w3 = src3.getWidth();
        h3 = src3.getHeight();
        
        
        w = src1.getWidth();
        h = src1.getHeight();
        tipo = BufferedImage.TYPE_3BYTE_BGR;
        dest = new BufferedImage(w, h, tipo);
        Raster srcR1 = src1.getRaster();
        Raster srcR2 = src2.getRaster();
        Raster srcR3 = src3.getRaster();
        WritableRaster destWR = dest.getRaster();
        
        
        for (int i = 0; i < h; i++) {
            for (int j = 0; j < w; j++) {
                nc1 = srcR1.getSample(j, i, 0);
                nc2 = srcR2.getSample(j, i, 0);
                nc3 = srcR3.getSample(j, i, 0);
                destWR.setSample(j, i, 0, nc1);
                destWR.setSample(j, i, 1, nc2);
                destWR.setSample(j, i, 2, nc3);
            }
        }
        
        return dest;
    }
    
    
    public FalsaCor(File file1, File file2, File file3, int tipoMetodo, JProgressBar barra) {
        barraStatus = barra;
        updateBarra("Gerando Falsa Cor, Aguarde!" , 10);
                
        // Define objeto BufferedImage para encapsular as imagens
        BufferedImage src1 = null, src2 = null, src3 = null, dest = null;
        int nc1, nc2, nc3, w, h, tipo;
        int w1, w2, w3, h1, h2, h3;
        // Certifica que as imagens existem
        
        try {
            src1 = ImageIO.read(file1);
        } catch(Exception e) {
            System.out.println("Imagem '" + file1.getName() + "' nao existe.");
            JOptionPane.showMessageDialog(this,"Imagem '" + file1.getName() + "' nao existe.");
            
            barraStatus.setValue(0);
            barraStatus.update(barraStatus.getGraphics());
        }
        
        try {
            src2 = ImageIO.read(file2);
        } catch(Exception e) {
            System.out.println("Imagem '" + file2.getName() + "' nao existe.");
            JOptionPane.showMessageDialog(this,"Imagem '" + file2.getName() + "' nao existe.");
            
            barraStatus.setValue(0);
            barraStatus.update(barraStatus.getGraphics());
        }
        
        try {
            src3 = ImageIO.read(file3);
        } catch(Exception e) {
            System.out.println("Imagem '" + file3.getName() + "' nao existe.");
            JOptionPane.showMessageDialog(this,"Imagem '" + file3.getName() + "' nao existe.");
            
            barraStatus.setValue(0);
            barraStatus.update(barraStatus.getGraphics());
        }
        
        // Acha as dimenses das imagens...
        w1 = src1.getWidth();
        h1 = src1.getHeight();
        w2 = src2.getWidth();
        h2 = src2.getHeight();
        w3 = src3.getWidth();
        h3 = src3.getHeight();
        
        //Verifica se as bandas tem o mesmo tamanho
          if ((w1 != w2) || (w1 != w3) || (h1 != h2) || (h1 != h3) ||
                (w2 != w3) || (h2 != h3)) {
            System.out.println("Bandas com dimenses diferentes!");
            JOptionPane.showMessageDialog(this,"No foi possivel realizar esta operao\n" +
                    "Tamanho diferente das bandas!",
                    "Erro: Tamanho das bandas",
                    JOptionPane.ERROR_MESSAGE);
            updateBarra("",0);
            return;
        }
        
        
        // Atribui nome ao frame
        String bandas = file1.getName() + ", " + file2.getName() +
                ", " + file3.getName();
        setName("Falsa cor: " + bandas);
        
        w = src1.getWidth();
        h = src1.getHeight();
        tipo = BufferedImage.TYPE_3BYTE_BGR;
        dest = new BufferedImage(w, h, tipo);
        Raster srcR1 = src1.getRaster();
        Raster srcR2 = src2.getRaster();
        Raster srcR3 = src3.getRaster();
        WritableRaster destWR = dest.getRaster();
        
        
        for (int i = 0; i < h; i++) {
            updateBarra("Montando imagem, Aguarde!", (int) (10 + (90*i)/h));
            for (int j = 0; j < w; j++) {
                nc1 = srcR1.getSample(j, i, 0);
                nc2 = srcR2.getSample(j, i, 0);
                nc3 = srcR3.getSample(j, i, 0);
                destWR.setSample(j, i, 0, nc1);
                destWR.setSample(j, i, 1, nc2);
                destWR.setSample(j, i, 2, nc3);
            }
        }
        
        // Define GUI com objetos do Swing
        JLabel limg = new JLabel(new ImageIcon(dest));
        this.setViewportView(limg);
        
        String search, prefixo, nome = null, nomeArquivo;
        search = ".";
        nomeArquivo = file1.getName();
        int i = nomeArquivo.indexOf(search);
        prefixo = nomeArquivo.substring(0, i);
        
        try {
            nome = "imagens\\" + prefixo + "_FC.png";
            File arq = new File(nome);
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            ImageIO.write(dest, "png", arq);
            
            ColorSpaceGui.imagensAbertas.add(new Manipulador(arq, 0, 1.00f));
        } catch (IOException e) {
            System.out.println("Problema gravando arquivo. ");
            System.exit(0);
        }
        
        updateBarra("Falsa Cor gerado com sucesso!" , 100);
        
        sucesso = true;
    }
    
    
    public boolean isSucesso() {
        return sucesso;
    }
}
