/*********************************************************************************
Fusao.java - Implementa a fuso espectral sobre as bandas pan, hue e saturation.

Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Implementa a fuso espectral sobre as bandas pan, hue e saturation.

Parmetros de entrada:

    1. Banda Pan.
    2. Banda Hue.
    3. Banda Saturation.
    4. Mtodo de interpolao.
    5. Barra de progresso da interface grafica principal.
 
Sada:
 
    1. Imagem da banda Red aps a Fuso.
    2. Imagem da banda Green aps a Fuso.
    3. Imagem da banda Blue aps a Fuso.
    4. Imagem colorida composta pelas bandas Red, Green e Blue.

Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda

**********************************************************************************/

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.image.BufferedImage;
import java.awt.image.Raster;
import java.awt.image.WritableRaster;
import java.io.File;
import java.io.IOException;
import java.util.Vector;
import javax.imageio.ImageIO;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;

public class Fusao extends JPanel {
    
    private boolean sucesso = false;
    private static int num =0;
    private File ImgRed;
    private File ImgGreen;
    private File ImgBlue;
    private File ImgIntensity;
    private File ImgHue;
    private File ImgSaturation;
    
    private JProgressBar barraStatus;
    
    private void updateBarra(String s, int n) {
        if(n%5 == 0) {
            barraStatus.setString(s);
            barraStatus.setValue(n);
            barraStatus.update(barraStatus.getGraphics());
        }
    }
    
    /** Creates a new instance of ColorTrasformacao */
    public Fusao(File filePan, File fileH ,File fileS, int tipoMetodo, JProgressBar jProgressBar1) {
        barraStatus = jProgressBar1;
        updateBarra("Preparando para Fuso, Aguarde!",5);
        
        // Define objeto BufferedImage para encapsular a imagem
        BufferedImage[] src = new BufferedImage[3];
        BufferedImage[] dest = new BufferedImage[3];
        BufferedImage falsa;
        JLabel img1, img2, img3, img4;
        int w, h;
        int numBandas, wP, hP, wH, hH, wS, hS;
        
        // L as trs bandas em nveis de cinza
        src[0] = abreImagem(filePan);    // Pan
        src[1] = abreImagem(fileH);    // hue
        src[2] = abreImagem(fileS);    // saturation
        // ... e checa se elas so iguais
        
        // Acha as dimenses das imagens...
        wP = src[0].getWidth();
        hP = src[0].getHeight();
        wH = src[1].getWidth();
        hH = src[1].getHeight();
        wS = src[2].getWidth();
        hS = src[2].getHeight();
        
        if ((wH != wS) || (hH != hS)) {
            System.out.println("Bandas Hue e Saturation Tamanhos diferentes!");
            JOptionPane.showMessageDialog(this,"No foi possivel realizar esta operao\n" +
                    "Tamanho diferente das bandas Hue e Saturation!",
                    "Erro: Tamanho das bandas",
                    JOptionPane.ERROR_MESSAGE);
            updateBarra("",0);
        }
        
        int maiorW = -1, maiorH = -1;
        
        System.out.println("wP: "+wP+" wH:"+wH+" wS:"+wS);
        System.out.println("hP: "+hP+" hH:"+hH+" hS:"+hS);
        
        // Descobre o fator de diferenca de tamanho
        float fatorX_H = (float) wP/wH;
        float fatorY_H = (float) hP/hH;
        src[1] = JAIZoom.Zoom(fileH.getPath(), fatorX_H, fatorY_H, tipoMetodo);
        updateBarra("Normalizando o tamanho da banda Hue!",15);
        
        float fatorX_S = (float) wP/wS;
        float fatorY_S = (float) hP/hS;
        src[2] = JAIZoom.Zoom(fileS.getPath(), fatorX_S, fatorY_S, tipoMetodo);
        updateBarra("Normalizando o tamanho da banda Saturation!",25);
        
        // Acha as dimenses das imagens...
        wP = src[0].getWidth();
        hP = src[0].getHeight();
        wH = src[1].getWidth();
        hH = src[1].getHeight();
        wS = src[2].getWidth();
        hS = src[2].getHeight();
        
        System.out.println("wP: "+wP+" wH:"+wH+" wS:"+wS);
        System.out.println("hP: "+hP+" hH:"+hH+" hS:"+hS);
        
        
        // Cortar a pan dependendo do algoritmo! 2 para o nilinear e 6 para o bicubico!
        int x1=0 ,x2=0 ,y1=0 ,y2=0;
        if(tipoMetodo == 2) {
            x1 = y1 = 2;
            x2 = src[0].getWidth() -2;
            y2 = src[0].getHeight() -2;
            
            src[0] = cortarImagem(x1,y1,x2,y2, src[0]);
            src[1] = cortarImagem(x1,y1,x2,y2, src[1]);
            src[2] = cortarImagem(x1,y1,x2,y2, src[2]);
        }else if (tipoMetodo == 3 || tipoMetodo == 4) {
            x1 = y1 = 6;
            x2 = src[0].getWidth() -6;
            y2 = src[0].getHeight() -6;
            
            src[0] = cortarImagem(x1,y1,x2,y2, src[0]);
            src[1] = cortarImagem(x1,y1,x2,y2, src[1]);
            src[2] = cortarImagem(x1,y1,x2,y2, src[2]);
        }
        
        updateBarra("Cortando as imagens, Aguarde!",35);
        
        // Certifica que cada banda est em nvel de cinza
        numBandas = src[0].getSampleModel().getNumBands();
        if (numBandas > 1) {
            String msgB = "\nImagem fornecida deve ter 1 banda.";
            String msgC = "numero de bandas atual = " + numBandas;
            JOptionPane.showMessageDialog(this,msgB+"\n" + msgC);
            return;
        }
        
        numBandas = src[1].getSampleModel().getNumBands();
        if (numBandas > 1) {
            String msgB = "\nImagem fornecida deve ter 1 banda.";
            String msgC = "numero de bandas atual = " + numBandas;
            JOptionPane.showMessageDialog(this,msgB+"\n" + msgC);
            return;
        }
        
        numBandas = src[2].getSampleModel().getNumBands();
        if (numBandas > 1) {
            String msgB = "\nImagem fornecida deve ter 1 banda.";
            String msgC = "numero de bandas atual = " + numBandas;
            JOptionPane.showMessageDialog(this,msgB+"\n" + msgC);
            return;
        }
        
        dest = converteIHS2RGB(src);
        updateBarra("Cortando as imagens, Aguarde!",65);
        
        falsa = FalsaCor.criaFalsa(dest[0],dest[1],dest[2]);
        updateBarra("Gerando falsa cor, Aguarde!",80);
        
        
        this.setName("ColorSpace " + filePan.getName());
        this.setLayout(new BorderLayout());
        JTabbedPane jTabbedPane1 = new JTabbedPane();
        img1 = new JLabel(new ImageIcon(dest[0]));
        img2 = new JLabel(new ImageIcon(dest[1]));
        img3 = new JLabel(new ImageIcon(dest[2]));
        img4 = new JLabel(new ImageIcon(falsa));
        
        jTabbedPane1.addTab("Red",new JScrollPane(img1));
        jTabbedPane1.addTab("Green",new JScrollPane(img2));
        jTabbedPane1.addTab("Blue",new JScrollPane(img3));
        jTabbedPane1.addTab("FalsaCor",new JScrollPane(img4));
        this.add(jTabbedPane1);
        
        File vFile[] = salvaImagem(dest, falsa , fileH.getName());
        
        Vector vect = new Vector();
        vect.add(jTabbedPane1);
        vect.add(new Manipulador(vFile[0],0,1.00f));
        vect.add(new Manipulador(vFile[1],1,1.00f));
        vect.add(new Manipulador(vFile[2],2,1.00f));
        vect.add(new Manipulador(vFile[3],2,1.00f));
        
        ColorSpaceGui.imagensAbertas.add(vect);
        updateBarra("Fusao Realizada com sucesso!",100);
        
        sucesso = true;
    }
    
    public BufferedImage[] converteIHS2RGB(BufferedImage[] src) {
        
        int wI, hI, wH, hH, wS, hS, tipo, iI, iH, iS, iR = 0, iG = 0, iB = 0, rgb;
        float intensity, hue, saturation;
        byte bR, bG, bB;
        BufferedImage[] out = new BufferedImage[3];
        
        // Acha as dimenses das imagens...
        wI = src[0].getWidth();
        hI = src[0].getHeight();
        
        // Gerar trs imagens separadas: vermelho, verde, azul
        // Posteriormente, elas podem ser combinadas numa imagem falsa cor.
        tipo = BufferedImage.TYPE_BYTE_GRAY;
        BufferedImage biR = new BufferedImage(wI, hI, tipo);
        BufferedImage biG = new BufferedImage(wI, hI, tipo);
        BufferedImage biB = new BufferedImage(wI, hI, tipo);
        
        Raster srcI = src[0].getRaster();	// intensity
        Raster srcH = src[1].getRaster();	// hue
        Raster srcS = src[2].getRaster();	// saturation
        
        WritableRaster wrR = biR.getRaster();	// red
        WritableRaster wrG = biG.getRaster();	// green
        WritableRaster wrB = biB.getRaster(); // blue
        
        
        System.out.println("Convertendo imagem...");
        
        for (int i = 0; i < hI; i++){
            updateBarra("Convertendo imagem, Aguarde!", (int) (36 + (30*i)/hI));
            
            for (int j = 0; j < wI; j++) {
                // L os pixels de cada banda
                iI = srcI.getSample(j, i, 0);
                iH = srcH.getSample(j, i, 0);
                iS = srcS.getSample(j, i, 0);
                
                // Normaliza intensity e saturation, de [0, 255] para [0.0, 1.0]
                // hue pode ser qualquer nmero em [0.0, 1.0]
                intensity  = (float)iI/255.0f;
                hue        = (float)iH/255.0f;
                saturation = (float)iS/255.0f;
                
                // Converte HSB para RGB
                rgb = Color.HSBtoRGB(hue, saturation, intensity);
                iR = (rgb>>16)&0xFF;
                iG = (rgb>>8)&0xFF;
                iB = rgb&0xFF;
                
                // Grava pixels R, G, B
                wrR.setSample(j, i, 0, iR);
                wrG.setSample(j, i, 0, iG);
                wrB.setSample(j, i, 0, iB);
            }
        }
        out[0] = biR;
        out[1] = biG;
        out[2] = biB;
        
        return out;
    }
    
// Salva imagens R, G, B no formato .PNG
    public File[] salvaImagem(BufferedImage[] dest,BufferedImage falsa, String nomeArquivo) {
        
        String search, prefixo, nome;
        File vFile[] = new File[4];
        
        // Grava imagem.
        search = ".";
        int i = nomeArquivo.indexOf(search);
        prefixo = nomeArquivo.substring(0, i);
        
        try {
            // imagem Red
            nome = "imagens\\" + prefixo + "_Fusao_R.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[0] = new File(nome);
            ImageIO.write(dest[0], "png", vFile[0]);
            
            // imagem Green
            updateBarra("Salvando as Imagens, Aguarde!",85);
            nome = "imagens\\" + prefixo + "_Fusao_G.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[1] = new File(nome);
            ImageIO.write(dest[1], "png", vFile[1]);
            
            // imagem Blue
            
            updateBarra("Salvando as Imagens, Aguarde!",90);
            nome = "imagens\\" + prefixo + "_Fusao_B.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[2] = new File(nome);
            ImageIO.write(dest[2], "png", vFile[2]);
            
            updateBarra("Salvando as Imagens, Aguarde!",95);
            nome = "imagens\\Fusao"+ prefixo + "_FC.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[3] = new File(nome);
            ImageIO.write(falsa, "png", vFile[3]);
        } catch (IOException e) {
            System.out.println("Problema gravando arquivo. ");
            System.exit(0);
        }
        
        return vFile;
    }
    
    
// Abre arquivo de imagens
    private BufferedImage abreImagem(File aFile) {
        BufferedImage imagem = null;
        
        try {
            imagem = ImageIO.read(aFile);
        } catch(Exception e) {
            System.out.println("abreImagens: Problema lendo '" + aFile + "'.");
        }
        return imagem;
    }
    
    private BufferedImage[] normalizacaoCor(BufferedImage[] src) {
        
        int wP = src[0].getWidth();
        int hP = src[0].getHeight();
        int wH = src[1].getWidth();
        int hH = src[1].getHeight();
        int wS = src[2].getWidth();
        int hS = src[2].getHeight();
        
        Raster srcP = src[0].getRaster();
        Raster srcH = src[1].getRaster();
        Raster srcS = src[2].getRaster();
        
        BufferedImage srcNovoH = new BufferedImage(wH, hH, BufferedImage.TYPE_BYTE_GRAY);
        BufferedImage srcNovoS = new BufferedImage(wS, hS, BufferedImage.TYPE_BYTE_GRAY);
        BufferedImage srcNovoT = new BufferedImage(wS, hS, BufferedImage.TYPE_BYTE_GRAY);
        
        WritableRaster rasterH = srcNovoH.getRaster();
        WritableRaster rasterS = srcNovoS.getRaster();
        WritableRaster rasterT = srcNovoT.getRaster();
        
        int somaH = 0, somaS = 0;
        
        for (int x = 0; x < wH; x++) {
            for (int y = 0; y < hH; y++) {
                somaH += srcH.getSample(x,y,0);
                somaS += srcS.getSample(x,y,0);
                rasterT.setSample(x,y,0,(srcH.getSample(x,y,0) + srcS.getSample(x,y,0)));
            }
        }
        
        System.out.println("SomaH"+ somaH);
        System.out.println("SomaS"+ somaS);
        
        for (int x = 0; x < wH; x++) {
            for (int y = 0; y < hH; y++) {
                //rasterH.setSample(x,y,0,((srcH.getSample(x,y,0) + 1)*(srcP.getSample(x,y,0) + 1)*3)/ (somaH + 3.0));
                //rasterS.setSample(x,y,0,((srcS.getSample(x,y,0) + 1)*(srcP.getSample(x,y,0) + 1)*3)/ (somaS + 3.0));
                rasterH.setSample(x,y,0,((srcH.getSample(x,y,0) + 1)*(srcP.getSample(x,y,0) + 1)*3)/ (rasterT.getSample(x,y,0) + 3.0)- 1);
                rasterS.setSample(x,y,0,((srcS.getSample(x,y,0) + 1)*(srcP.getSample(x,y,0) + 1)*3)/ (rasterT.getSample(x,y,0) + 3.0) -1);
            }
        }
        
        src[1] = srcNovoH;
        src[2] = srcNovoS;
        
        return src;
    }
    
    private BufferedImage cortarImagem(int x1, int y1, int x2, int y2, BufferedImage imagem) {
        
        int wi = imagem.getWidth();
        int hi = imagem.getHeight();
        
        Raster imgRaster = imagem.getRaster();
        
        BufferedImage novaImagem = new BufferedImage(x2-x1, y2-y1, BufferedImage.TYPE_BYTE_GRAY);
        WritableRaster rasterNovo = novaImagem.getRaster();
        
        for (int x = 0; x < x2-x1; x++) {
            for (int y = 0; y < y2-y1; y++) {
                rasterNovo.setSample(x,y,0,imgRaster.getSample(x+x1,y+y1,0));
            }
        }
        
        return novaImagem;
    }
    
    public boolean isSucesso() {
        return sucesso;
    }
    
}





