/*********************************************************************************
HistogramaFC.java - Gera o histograma para uma determinada imagem utilizando o 
                    pacote JFreeChart, verso 0.9.8+.

Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Gera o histograma para uma determinada imagem.

Parmetros de entrada:

    1. Arquivo de imagem
    2. Titulo do histograma
 
Sada:
 
    1. Janela com o histograma criado;
 
Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda
 
**********************************************************************************/

import java.awt.Toolkit;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartFrame;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.Plot;
import java.text.DecimalFormat;

import java.awt.image.BufferedImage;
import java.awt.image.Raster;
import java.awt.GradientPaint;
import java.awt.Color;
import java.awt.Paint;
import javax.swing.JOptionPane;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.title.TextTitle;
import org.jfree.data.xy.XYDataset;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;

public class HistogramaFC{
    private static int count = 0;
    
    public HistogramaFC(BufferedImage src, String titulo) { 
        count++;
        if(count > 10) {
            JOptionPane.showMessageDialog(null,"Nmero mximo de histogramas abertos atingido = 10",
                        "Erro: Imagem no reconhecida",JOptionPane.ERROR_MESSAGE);
        }
        int w, h;
        int[] hist = new int[256];
                
        Raster srcR = src.getRaster();
        w = src.getWidth();
        h = src.getHeight();
        
        // Calcula o histograma
        for (int i = 0; i < 256; i++)
            hist[i] = 0;
        for (int i = 0; i < h; i++)
            for (int j = 0; j < w; j++)
                hist[srcR.getSample(j, i, 0)]++;
        
        // Cria o arquivo de dados...
        XYSeries dataset = new XYSeries("Densidade probabilidade");
        for (int i = 0; i < 256; i++) {
            dataset.add(i, hist[i]);
        }
        
        XYDataset xyDataSet = new XYSeriesCollection(dataset);
        
        // Cria o grfico...
        JFreeChart chart = ChartFactory.createXYAreaChart("Histograma",
                "nvel de cinza",
                "Freqncia",
                xyDataSet,
                PlotOrientation.VERTICAL,
                false,
                true,
                true
                );
        
        // Cria e mostra um frame...
        ChartFrame frame = new ChartFrame("Histograma", chart);
        
        // Personaliza apresentao do histograma
        // Adiciona sub-ttulo
        TextTitle subTitulo = new TextTitle(titulo);
        chart.addSubtitle(subTitulo);
        
        // Adiciona segundo sub-ttulo com estatsticas da imagem
        double[] stats = moment(src);
        
        String padrao = "###.###";
        DecimalFormat formato = null;
        formato = new DecimalFormat(padrao);
        
        String media = formato.format(stats[0]);
        String desvi = formato.format(stats[1]);
        String minim = String.valueOf(stats[3]);
        String maxim = String.valueOf(stats[4]);
        
        String texto = "Mdia = " + media + "; " + "D.P. = " + desvi + "; "
                + "Mnimo = " + minim + "; " + "Mximo = " + maxim;
        TextTitle subTituloEstat = new TextTitle(texto);
        chart.addSubtitle(subTituloEstat);
        
        // Cor de fundo do quadro
        Paint pq = new GradientPaint(0, 0, Color.white, 1000, 0, Color.blue);
        chart.setBackgroundPaint(pq);
        
        // Cor de fundo da rea do grfico
        Plot plot = chart.getPlot();
        Paint pc = new GradientPaint(0, 0, Color.green, 1000, 0, Color.white);
        plot.setBackgroundPaint(pc);
        
        
        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        frame.setBounds((screenSize.width-frame.getWidth())/4, (screenSize.height-frame.getHeight())/4, 
                frame.getWidth(), frame.getHeight());
        
        frame.setIconImage(Toolkit.getDefaultToolkit().getImage("src//chart_bar.png"));
        
        frame.pack();
        frame.setVisible(true);
    }
    
    // Calcula momentos estatstico
    private static double[] moment(BufferedImage src) {
        
        // Array para armazenar valores estatsticos da imagem
        double[] stats = new double[5];
    /*
     stats[0] = mdia
     stats[1] = desvio padro
     stats[2] = varincia
     stats[3] = valor mnimo
     stats[4] = valor mximo
     */
        double ep = 0.0, sum, p;
        int w, h, N, pixel;
        
        Raster raster = src.getRaster();
        
        for (int i = 0; i < 5; i++)
            stats[i] = 0.0;
        stats[2] = 255.0;
        
        // Passo 1: Calcula a mdia, mnimo e mximo
        sum = 0.0;
        w = src.getWidth();
        h = src.getHeight();
        N = w*h;
        
        for (int i = 0; i < h; i++)
            for (int j = 0; j < w; j++) {
            pixel = raster.getSample(j, i, 0);
            sum += pixel;
            stats[3] = Math.min(stats[3], pixel);
            stats[4] = Math.max(stats[4], pixel);
            }
        stats[0] = (double)sum/N;
        
        // Passo 2: calcula segundo e terceiro momentos estatsticos
        for (int i = 0; i < h; i++)
            for (int j = 0; j < w; j++) {
            sum = raster.getSample(j, i, 0) - stats[0];
            ep += sum;
            stats[2] += (p = sum*sum);
            }
        stats[2] = (stats[2] - ep*ep/N)/(N-1);
        stats[1] = Math.sqrt(stats[2]);
        
        return(stats);
    }
    
}