/*********************************************************************************
JAIZoom.java - Amplia ou reduz tamanho da imagem com JAI (Java Advanced Imaging).
 
Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Amplia ou reduz tamanho da imagem com JAI (Java Advanced Imaging).

Parmetros de entrada:

    1. Caminho para o arquivo de imagem.
    2. Fator de ampliao em X.
    3. Fator de ampliao em Y.
    4. Mtodo de interpolao.
 
Sada:

    Imagem atualizada conforme as entradas.

Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda
 
**********************************************************************************/

// pacote genrico
import java.io.File;

// pacotes do AWT
import java.awt.image.renderable.ParameterBlock;
import java.awt.image.AffineTransformOp;
import java.awt.image.BufferedImage;

import java.awt.geom.AffineTransform;
import java.awt.GridLayout;

// pacote Swing para interface grfica
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JScrollPane;
import javax.swing.ImageIcon;

// pacotes do JAI
import javax.media.jai.JAI;
import javax.media.jai.RenderedOp;
import javax.media.jai.PlanarImage;
import javax.media.jai.Interpolation;

// leitura em modo imediato - para J2SE 1.4+
import javax.imageio.ImageIO;

public class JAIZoom{
    
    public static final BufferedImage Zoom(String aFile, float afatorX, float afatorY, int atipoInter) {
        PlanarImage pImage = null;
        Interpolation interp = null;
        
        // Certifica que a imagem existe
        try {
            pImage = JAI.create("fileload", aFile);
            System.out.println("[ JAIZoom ][ Carregando imagem '" + aFile + "']");
        } catch (Exception e) {
            System.out.println("[ JAIZoom ][ Arquivo " + aFile + " com problemas.]");
            System.exit(0);
        }
        
        // Atribui nome ao frame
        File tmpFile = new File(aFile);
        // Amplia/Reduz imagem pelos fatores afatorX e afatorY
        // Especifica o mtodo de interpolao
        switch (atipoInter){
            case 1:
                interp = Interpolation.getInstance(Interpolation.INTERP_NEAREST);
                System.out.println("[ JAIZoom ][ Interpolador usado ==> INTERP_NEAREST]");
                break;
            case 2:
                interp = Interpolation.getInstance(Interpolation.INTERP_BILINEAR);
                System.out.println("[ JAIZoom ][ Interpolador usado ==> INTERP_BILINEAR]");
                break;
            case 3:
                interp = Interpolation.getInstance(Interpolation.INTERP_BICUBIC);                
                System.out.println("[ JAIZoom ][ Interpolador usado ==> INTERP_BICUBIC]");
                break;
            case 4:
                interp = Interpolation.getInstance(Interpolation.INTERP_BICUBIC_2);
                System.out.println("[ JAIZoom ][ Interpolador usado ==> INTERP_BICUBIC_2]");
                break;
        }
        
        System.out.println("[ JAIZoom ][ Fator x:" +afatorX + " Fator y:" + afatorY +"]");
        
        ParameterBlock pb = new ParameterBlock();
        pb.addSource(pImage);                     // imagem fonte
        pb.add(afatorX);                          // fator X
        pb.add(afatorY);                          // fator Y
        pb.add(0.0f);                             // sem translao X
        pb.add(0.0f);                             // sem translao Y
        pb.add(interp);                           // tipo de interpolao
        
        pImage = JAI.create("Scale", pb, null);
        
        return pImage.getAsBufferedImage();
    }
}
