/*********************************************************************************
RGB2HLS.java - Converte trs bandas, em nveis de cinza, do espao de cores RGB 
               (Red, Green, Blue), para o espao de cores HLS (Hue, Lightness, 
               Saturation).
 
Direitos Autorais Reservados (c) 2007 Embrapa Informtica Agropecuria

Este programa  software livre; voc pode redistribu-lo e/ou modific-lo sob os
termos da Licena Pblica Geral GNU conforme publicada pela Free Software
Foundation; tanto a verso 2 da Licena, como (a seu critrio) qualquer verso
posterior.

Este programa  distribudo na expectativa de que seja til, porm, SEM NENHUMA
GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU ADEQUAO A UMA
FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral do GNU para mais detalhes.

Voc deve ter recebido uma cpia da Licena Pblica Geral do GNU junto com este
programa; se no, escreva para a Free Software Foundation, Inc., no endereo 59
Temple Street, Suite 330, Boston, MA 02111-1307 USA.

**********************************************************************************

Parte integrante do software 'Fuso espectral de imagens de satlite no espao de cores'

Descrio:

    Converte uma as bandas RGB para o espao de cores HLS.

Parmetros de entrada:

    1. banda corresponde ao espectro do vermelho;
    2. banda corresponde ao espectro do verde;
    3. banda corresponde ao espectro do azul.
 
Sada:
 
    1. banda Hue;
    2. banda Lightness;
    3. banda Saturation.

Mais informaes, nas pginas 35 do Pitas e 592 do Foley et al.:
    1. Pitas, I. Digital image processing algorithms and applications.
          New York,NY:John Wiley & Sons Inc, 2000. 419p.
    2. Foley, J.D.; A. van Dam; S.K. Feiner; J.F. Hughes. Computer graphics:
          principles and practice, NY:Addison-Wesley, 1990. 1174p.
 
Desenvolvido por:
   
    Marcello Antonio Marabita
    Jos Iguelmar Miranda
 
**********************************************************************************/

// pacotes genricos
import java.awt.color.ColorSpace;
import java.io.File;
import java.io.IOException;
import java.util.Vector;

// pacotes do AWT
import java.awt.BorderLayout;
import java.awt.image.BufferedImage;
import java.awt.image.WritableRaster;
import java.awt.image.Raster;

// pacote Swing para interface grfica
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.ImageIcon;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JFileChooser;

// leitura em modo imediato - para J2SE 1.4+
import javax.imageio.ImageIO;
import javax.swing.JTabbedPane;

public class RGB2HLS extends JPanel {
    
    private JProgressBar barraStatus;
    private boolean sucesso = false;
    
    private void updateBarra(String s, int n) {
        if(n%5 == 0) {
            barraStatus.setString(s);
            barraStatus.setValue(n);
            barraStatus.update(barraStatus.getGraphics());
        }
    }
        
    // ********* Construtor #2: para tratar bandas separadas *************
    public RGB2HLS(File fileR, File fileG, File fileB, int tipoMetodo, JProgressBar barra) {
        barraStatus = barra;
        updateBarra("Preparando para Converter, Aguarde!",5);
        
        int numBandas, wR, hR, wG, hG, wB, hB, tipo;
        JLabel img1, img2, img3;
        BufferedImage[] src = new BufferedImage[3];
        BufferedImage[] dest = new BufferedImage[3];
        
        // L as trs bandas em nveis de cinza
        src[0] = abreImagem(fileR);
        src[1] = abreImagem(fileG);
        src[2] = abreImagem(fileB);
        
        // Acha as dimenses das imagens...
        wR = src[0].getWidth();
        hR = src[0].getHeight();
        wG = src[1].getWidth();
        hG = src[1].getHeight();
        wB = src[2].getWidth();
        hB = src[2].getHeight();
        
        // ... e checa se elas so iguais
        if ((wR != wG) || (wR != wB) || (hR != hG) || (hR != hB) ||
                (wB != wG) || (hB != hG)) {
            System.out.println("Bandas com dimenses diferentes!");
            JOptionPane.showMessageDialog(this,"No foi possivel realizar esta operao\n" +
                    "Tamanho diferente das bandas!",
                    "Erro: Tamanho das bandas",
                    JOptionPane.ERROR_MESSAGE);
            updateBarra("",0);
            return ;
        }
       
        
        // Certifica que cada banda est em nvel de cinza
        numBandas = src[0].getSampleModel().getNumBands();
        if (numBandas > 1) {
            String msgA = "Convertendo para HLS: ";
            String msgB = "\nImagem fornecida da banda vermelha *DEVE* ter 1 banda.";
            String msgC = "#bandas atual = " + numBandas;
            System.out.println(msgA + msgB + "\n" + msgC + ". Abortando...");
            JOptionPane.showMessageDialog(this,msgA+msgB+"\n" + msgC);
            updateBarra("",0);
            return;
        }
        
        numBandas = src[1].getSampleModel().getNumBands();
        if (numBandas > 1) {
            String msgA = "Convertendo para HLS: ";
            String msgB = "\nImagem fornecida da banda verde *DEVE* ter 1 banda.";
            String msgC = "#bandas atual = " + numBandas;
            JOptionPane.showMessageDialog(this,msgA+msgB+"\n" + msgC);
            updateBarra("",0);
            return;
        }
        
        numBandas = src[2].getSampleModel().getNumBands();
        if (numBandas > 1) {
            String msgA = "Convertendo para HLS: ";
            String msgB = "\nImagem fornecida da banda azul *DEVE* ter 1 banda.";
            String msgC = "#bandas atual = " + numBandas;
            JOptionPane.showMessageDialog(this,msgA+msgB+"\n" + msgC);
            updateBarra("",0);
            return;
        }
        // Ttulo do JFrame
        
        
        updateBarra("Convertendo imagem, Aguarde!",25);
        setName("RGB-HLS: " + fileR.getName());
        // Transforma espao de cores RGB para HLS
        dest = converteRGB2HLS(src);
        
        updateBarra("Criando a Interface grafica, Aguarde!",70);
        
        this.setLayout(new BorderLayout());
        img1 = new JLabel(new ImageIcon(dest[0]));
        img2 = new JLabel(new ImageIcon(dest[1]));
        img3 = new JLabel(new ImageIcon(dest[2]));
        
        JTabbedPane jTabbedPane1 = new JTabbedPane();
        
        jTabbedPane1.addTab("Hue", new JScrollPane(img1));
        jTabbedPane1.addTab("Lightness",new JScrollPane(img2));
        jTabbedPane1.addTab("Saturation",new JScrollPane(img3));
        this.add(jTabbedPane1); 
        updateBarra("Criando a Interface grafica, Aguarde!",75);
        
        // Salva arquivos de sada formato PNG
        File vFile[] = salvaImagem(dest, fileR.getName());
        
        Vector vect = new Vector();
        vect.add(jTabbedPane1);
        vect.add(new Manipulador(vFile[0],0,1.00f));
        vect.add(new Manipulador(vFile[1],1,1.00f));
        vect.add(new Manipulador(vFile[2],2,1.00f));
        
        ColorSpaceGui.imagensAbertas.add(vect);
        
        updateBarra("Imagem Convertida: RGB para HLS",100);
        sucesso = true;
    }  // fim Construtor
    
    
    // MTODOS PBLICOS
    
    public BufferedImage[] separaRGB(BufferedImage src) {
        int w, h, tipo, nc1, nc2, nc3;
        
        BufferedImage[] out = new BufferedImage[3];
        WritableRaster[] wrOut = new WritableRaster[3];
        w = src.getWidth();
        h = src.getHeight();
        tipo = BufferedImage.TYPE_BYTE_GRAY;
        out[0] = new BufferedImage(w, h, tipo);
        out[1] = new BufferedImage(w, h, tipo);
        out[2] = new BufferedImage(w, h, tipo);
        
        Raster rSrc = src.getRaster();
        WritableRaster wrRed   = out[0].getRaster();
        WritableRaster wrGreen = out[1].getRaster();
        WritableRaster wrBlue  = out[2].getRaster();
        
        for (int lin = 0; lin < h; lin++) {
            for (int col = 0; col < w; col++) {
                nc1 = rSrc.getSample(col, lin, 0);
                nc2 = rSrc.getSample(col, lin, 1);
                nc3 = rSrc.getSample(col, lin, 2);
                wrRed.setSample(col, lin, 0, nc1);
                wrGreen.setSample(col, lin, 0, nc2);
                wrBlue.setSample(col, lin, 0, nc3);
            }
        }
        return out;
    }
    
    public BufferedImage[] converteRGB2HLS(BufferedImage[] src) {
        
        int wR, hR, wG, hG, wB, hB, tipo, r, g, b;
        byte bLight, bSatur, bHue;
        double hue = 0.0, lightness, saturation, max, min, delta, UNDEFINED = 360.0,
                dR, dG, dB;
        BufferedImage[] out = new BufferedImage[3];
        
        wR = src[0].getWidth();
        hR = src[0].getHeight();
    
        // Gerar trs imagens separadas: hue, lig (lightness), sat (saturation)
        // Posteriormente, elas podem ser combinadas numa imagem falsa cor.
        tipo = BufferedImage.TYPE_BYTE_GRAY;
        BufferedImage biHue = new BufferedImage(wR, hR, tipo);
        BufferedImage biLig = new BufferedImage(wR, hR, tipo);
        BufferedImage biSat = new BufferedImage(wR, hR, tipo);
        
        Raster srcR = src[0].getRaster();
        Raster srcG = src[1].getRaster();
        Raster srcB = src[2].getRaster();
        
        WritableRaster wrHue = biHue.getRaster();
        WritableRaster wrLig = biLig.getRaster();
        WritableRaster wrSat = biSat.getRaster();
        
        updateBarra("Convertendo imagem, Aguarde!",30);
        
        System.out.println("Convertendo imagem...");
        
        int contaUNDEFINED = 0;
        
        for (int i = 0; i < hR; i++) {
            // Calculo para a barra
            updateBarra("Convertendo imagem, Aguarde!", (int) (31 + (40*i)/hR));

            for (int j = 0; j < wR; j++) {
                r = srcR.getSample(j, i, 0);
                g = srcG.getSample(j, i, 0);
                b = srcB.getSample(j, i, 0);
                
                // Normaliza r, g, b para o intervalo [0.0, 1.0]
                dR = (double)r/255.0;
                dG = (double)g/255.0;
                dB = (double)b/255.0;
                
                // Acha os valores mximo e mnimo
                // max = maximum(r, g, b);
                // min = minimum(r, g, b);
                max = dR;
                if (max < dG)
                    max = dG;
                if (max < dB)
                    max = dB;
                min = dR;
                if (min > dG)
                    min = dG;
                if (min > dB)
                    min = dB;
                
                //  desejado:
                //  hue em [0, 360), lightness e saturation em [0, 1],
                //  exceto quando saturation = 0, ento hue = UNDEFINED.
                
                // Calcula o valor de Lightness, em [0.0, 1.0]
                lightness = (max + min)/2.0;
                
                // Calcula Saturation, em [0.0, 1.0]
                if (max == min) {
                    // Caso acromtico, porque r = g = b
                    saturation = 0.0;
                    hue = UNDEFINED;
                    contaUNDEFINED++;
                } else {
                    // Caso cromtico
                    // Primeiro, calcula Saturation, em [0.0, 1.0]
                    delta = max - min;
                    if (lightness <= 0.5)
                        saturation = delta/(max + min);
                    else
                        saturation = delta/(2.0 - max - min);
                    // Segundo, calcula Hue, em [0.0, 360.0)
                    if (dR == max)
                        // Cor resultante est entre amarelo e magenta
                        hue = (dG - dB)/delta;
                    else {
                        if (dG == max)
                            // Cor resultante est entre cyan e amarelo
                            hue = 2.0 + (dB - dR)/delta;
                        else
                            // Cor resultante est entre magenta e cyan
                            if (dB == max)
                                hue = 4.0 + (dR - dG)/delta;
                    }
                    // Converte hue para graus
                    if(hue != UNDEFINED)
                        hue *= 60.0;
                    // Define Hue com graus positivos
                    if (hue < 0.0)
                        hue += 360.0;
                }
                
                //  Converte Lightness e Saturation, intervalo [0.0, 1.0],
                //  e Hue, [0.0, 360.0], para [0, 255]
                bHue   = (byte)((hue/360.0)*255);
                bLight = (byte)(lightness*255);
                bSatur = (byte)(saturation*255);
                
                // Salva imagens
                wrHue.setSample(j, i, 0, bHue);
                wrLig.setSample(j, i, 0, bLight);
                wrSat.setSample(j, i, 0, bSatur);
            }
        }
        
        
        out[0] = biHue;
        out[1] = biLig;
        out[2] = biSat;
        System.out.println("contaUNDEFINED = " + contaUNDEFINED);
        return out;
    }
    
    // Salva imagens H, L, S no formato .PNG
    public File[] salvaImagem(BufferedImage[] dest, String nomeArquivo) {
        
        String search, prefixo, nome;
        File vFile[] = new File[3];
        
        // Grava imagem.
        search = ".";
        int i = nomeArquivo.indexOf(search);
        prefixo = nomeArquivo.substring(0, i);
        
        try {
            
            updateBarra("Salvando as Imagens, Aguarde!",80);
            // imagem Hue Intensity
            nome = "imagens\\" + prefixo + "_HLS_H.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[0] = new File(nome);
            ImageIO.write(dest[0], "png", vFile[0]);
            
            // imagem Intensity (Lightness)
            updateBarra("Salvando as Imagens, Aguarde!",85);
            nome = "imagens\\" + prefixo + "_HLS_L.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[1] = new File(nome);
            ImageIO.write(dest[1], "png", vFile[1]);
            
            // imagem Saturation
            updateBarra("Salvando as Imagens, Aguarde!",90);
            nome = "imagens\\" + prefixo + "_HLS_S.png";
            System.out.println("\nGravou arquivo -> " + nome + "\n");
            vFile[2] = new File(nome);
            ImageIO.write(dest[2], "png", vFile[2]);
        } catch (IOException e) {
            System.out.println("Problema gravando arquivo. ");
            System.exit(0);
        }
        
        return vFile;
    }
    
    // Abre arquivo de imagens
    private BufferedImage abreImagem(File aFile) {
        BufferedImage imagem = null;
        
        try {
            imagem = ImageIO.read(aFile);
        } catch(Exception e) {
            System.out.println("abreImagens: Problema lendo '" + aFile + "'.");
        }
        return imagem;
    }
    
    public boolean isSucesso() {
        return sucesso;
    }
}
